* SPSS code prepared for the Western Libraries Map and Data Centre, UWO by Vince Gray.

* replace [path] in the data list and the write file command with the location(s) from which you are reading
*  the input file and to which you wish to save the output file.

data list file='[path]\pccfNat_JUN13_fccpNat.txt' /
 REGION    1 (A)
 FSA       7-9 (A)
 PSTLCODE  1-6 (A)
 PROVINCE  10-11
 cduid     12-15
 CSDUID    16-22
 CSDNAME   23-92 (A)
 CSDTYPE   93-95 (A)
 CCScode   96-98
 SAC       99-101
 SACTYPE   102
 CTNAME    103-109 (A)
 ER        110-111
 DPL       112-115
 FED03UID  116-120
 PCRAcode  121-124
 PCRATYPE  125
 DAUID     126-133
 BLOCKCOD  134-135
 REPPOINT  136
 LATITUDE  137-147 (6)
 LONGITUD  148-160 (6)
 SLI       161
 PCTYPE    162
 COMMNAME  163-192 (a)
 DMT       193 (A)
 HDMT      194 (A)
 BRTHDATE  195-202
 RTRDDATE  203-210
 PO        211
 QI        212-214 (A)
 QI1       212 (A)
 QI2       213 (A)
 QI3       214 (A)
 SOURCE    215
 PCRASIZE  216.

* This statement sorts all records in the file in ascending order by postal code, birth date, and retirement date
* of the postal code. 

sort cases by pstlcode (A) brthdate (A) rtrddate (A).

* The select statement below create a "Best Match" file, which contains all active, non-retired postal codes which are 
*  identified as the single best identifier.

* If an "All Record" file (unfiltered by the best match or retirement) is desired, comment out the select if command by
*  placing an asterisk in front of "select".

select if (sli=1) and (rtrddate=19000001).

* This creates a numeric unique identifier for each record in the file (whether best match or all records). Since in the
*  all records file, postal codes are not unique, this provides a single variable to match records against.

compute recnumbr=$casenum.

* This creates a uniquely identified economic region by appending the variable ER to the variable province. It allows
*  value labels (names) to be associated with the economic region, or to select ERs with a single variable.

compute new_er=province*100+er.

* This creates a uniquely identified designated place by appending the variable DPL to the variable province. It allows
*  value labels (names) to be associated with the designated place, or users to select DPLs with a single variable.

compute new_dpl=province*10000+dpl.

* This creates a uniquely identified census consolidated subdivision by appending the variable CCS to the variable province.
*  It allows value labels (names) to be associated with the census consolidated subdivision (which has not been done), or
*  users to select CCSs with a single variable.

compute ccsuid=cduid*1000+ccscode.

* This creates a uniquely identified urban area by appending the variable PCRACODE to the variable province.
*  It allows value labels (names) to be associated with the urban area, or users to select UAs with a single variable.

compute urbnarea=PCRACODE+province*10000.

* This creates a uniquely identified block by appending the variable blockcod to the variable dauid.

compute blockuid=dauid*100+blockcod.

* For coding purposes associated with Equinox (SQL does not like blanks in numeric fields), this replaces blanks in
*  numeric fields with explicit numeric codes which will be identified as missing values.

recode PCRACODE PCRATYPE urbnarea (sysmis=0).

* The formats statement establishes the size and type of variable to be used (F: numeric, #= total number of columns),
*  and the number of decimals (in all cases below, 0). So, values of new_er may range from 0 through 9999.

formats
 recnumbr (F7.0)
 new_er (F4.0)
 new_dpl urbnarea (F6.0)
 ccsuid (F8.0)
 blockuid (F10.0).

variable labels
 region   "Region (First character of postal code identifies province, territory or sub-provincial region)"
 FSA      "Forward Sortation Area"
 PSTLCODE "Postal code"
 PROVINCE "Province or territory"
 cDuid    "Census division (explicit indentifier)"
 csduid   "Census Subdivision (explicit indentifier)"
 CSDNAME  "Census subdivision name"
 CSDTYPE  "Census subdivision type"
 ccscode  "Census consolidated subdivision code"
 sac      "Statistical Area Classification (includes CMA/CA designation)"
 SACTYPE  "Statistical Area Classification type"
 ctname   "Census Tract Name (must be used with CMA code)"
 ER       "Economic region (ER) code - unmodified"
 DPL      "Designated place (DPL) code - unmodified"
 FED03UID "Federal Electoral District (2003 Representation Order)"
 PCRACODE "Population centre/rural area code (non-unique)"
 pcratype "Population centre/rural area type: relationship within CMA/CA structure"
 dauID    "Dissemination area (explicit identifier)"
 BLockcod "Block code (must be used with DA_UID to explicitly identify areas): see BLOCKUID"
 blockuid "Block unique identifier (DA_UID * 100 + BLOCKCOD)"
 REPPOINT "Representative point type"
 LATITUDE "Latitude"
 LONGITUD "Longitude"
 SLI      "Single link indicator/Best link indicator"
 PCTYPE   "Postal code type"
 COMMNAME "Community name"
 DMT      "Delivery mode type"
 HDMT     "Historic delivery mode type"
 BRTHDATE "Postal code birth date"
 RTRDDATE "Postal code retired date"
 PO       "Delivery installation"
 QI       "Overall quality indicator"
 QI1      "Quality Indicator: general area"
 QI2      "Quality Indicator: match to correct street"
 QI3      "Quality Indicator: match to correct address range"
 SOURCE   "Source of Geocoding"
 recnumbr "Record identifier (used for matching data extractions)"
 new_er   "Economic Region (explicit indentifier)"
 new_dpl  "Designated Place (explicit indentifier)"
 urbnarea "Urban area, explicitly identified with province"
 ccsuid   "Census Consolidated Subdivision (explicit indentifier)"
 .

Value labels
 REGION
 "A" "Newfoundland and Labrador"
 "B" "Nova Scotia"
 "C" "Prince Edward Island"
 "E" "New Brunswick"
 "G" "Eastern Qubec"
 "H" "Metropolitan Montral"
 "J" "Western Qubec"
 "K" "Eastern Ontario"
 "L" "Central Ontario"
 "M" "Metropolitan Toronto"
 "N" "Southwestern Ontario"
 "P" "Northern Ontario"
 "R" "Manitoba"
 "S" "Saskatchewan"
 "T" "Alberta"
 "V" "British Columbia"
 "X" "Northwest Territories and Nunavut"
 "Y" "Yukon Territory"
 /
 FSA
 /
 PSTLCODE
 /
 PROVINCE
 10 "Newfoundland and Labrador"
 11 "Prince Edward Island"
 12 "Nova Scotia"
 13 "New Brunswick"
 24 "Quebec"
 35 "Ontario"
 46 "Manitoba"
 47 "Saskatchewan"
 48 "Alberta"
 59 "British Columbia"
 60 "Yukon Territory"
 61 "Northwest Territories"
 62 "Nunavut"
 /
 cduid
 1001 "Division No.  1"
 1002 "Division No.  2"
 1003 "Division No.  3"
 1004 "Division No.  4"
 1005 "Division No.  5"
 1006 "Division No.  6"
 1007 "Division No.  7"
 1008 "Division No.  8"
 1009 "Division No.  9"
 1010 "Division No. 10"
 1011 "Division No. 11"
 1101 "Kings"
 1102 "Queens"
 1103 "Prince"
 1201 "Shelburne"
 1202 "Yarmouth"
 1203 "Digby"
 1204 "Queens"
 1205 "Annapolis"
 1206 "Lunenburg"
 1207 "Kings"
 1208 "Hants"
 1209 "Halifax"
 1210 "Colchester"
 1211 "Cumberland"
 1212 "Pictou"
 1213 "Guysborough"
 1214 "Antigonish"
 1215 "Inverness"
 1216 "Richmond"
 1217 "Cape Breton"
 1218 "Victoria"
 1301 "Saint John"
 1302 "Charlotte"
 1303 "Sunbury"
 1304 "Queens"
 1305 "Kings"
 1306 "Albert"
 1307 "Westmorland"
 1308 "Kent"
 1309 "Northumberland"
 1310 "York"
 1311 "Carleton"
 1312 "Victoria"
 1313 "Madawaska"
 1314 "Restigouche"
 1315 "Gloucester"
 2401 "Les les-de-la-Madeleine"
 2402 "Le Rocher-Perc"
 2403 "La Cte-de-Gasp"
 2404 "La Haute-Gaspsie"
 2405 "Bonaventure"
 2406 "Avignon"
 2407 "La Matapdia"
 2408 "Matane"
 2409 "La Mitis"
 2410 "Rimouski-Neigette"
 2411 "Les Basques"
 2412 "Rivire-du-Loup"
 2413 "Tmiscouata"
 2414 "Kamouraska"
 2415 "Charlevoix-Est"
 2416 "Charlevoix"
 2417 "L'Islet"
 2418 "Montmagny"
 2419 "Bellechasse"
 2420 "L'le-d'Orlans"
 2421 "La Cte-de-Beaupr"
 2422 "La Jacques-Cartier"
 2423 "Qubec"
 2425 "Lvis"
 2426 "La Nouvelle-Beauce"
 2427 "Robert-Cliche"
 2428 "Les Etchemins"
 2429 "Beauce-Sartigan"
 2430 "Le Granit"
 2431 "L'Amiante"
 2432 "L'rable"
 2433 "Lotbinire"
 2434 "Portneuf"
 2435 "Mkinac"
 2436 "Shawinigan"
 2437 "Francheville"
 2438 "Bcancour"
 2439 "Arthabaska"
 2440 "Asbestos"
 2441 "Le Haut-Saint-Franois"
 2442 "Le Val-Saint-Franois"
 2443 "Sherbrooke"
 2444 "Coaticook"
 2445 "Memphrmagog"
 2446 "Brome-Missisquoi"
 2447 "La Haute-Yamaska"
 2448 "Acton"
 2449 "Drummond"
 2450 "Nicolet-Yamaska"
 2451 "Maskinong"
 2452 "D'Autray"
 2453 "Le Bas-Richelieu"
 2454 "Les Maskoutains"
 2455 "Rouville"
 2456 "Le Haut-Richelieu"
 2457 "La Valle-du-Richelieu"
 2458 "Longueuil"
 2459 "Lajemmerais"
 2460 "L'Assomption"
 2461 "Joliette"
 2462 "Matawinie"
 2463 "Montcalm"
 2464 "Les Moulins"
 2465 "Laval"
 2466 "Montral"
 2467 "Roussillon"
 2468 "Les Jardins-de-Napierville"
 2469 "Le Haut-Saint-Laurent"
 2470 "Beauharnois-Salaberry"
 2471 "Vaudreuil-Soulanges"
 2472 "Deux-Montagnes"
 2473 "Thrse-De Blainville"
 2474 "Mirabel"
 2475 "La Rivire-du-Nord"
 2476 "Argenteuil"
 2477 "Les Pays-d'en-Haut"
 2478 "Les Laurentides"
 2479 "Antoine-Labelle"
 2480 "Papineau"
 2481 "Gatineau"
 2482 "Les Collines-de-l'Outaouais"
 2483 "La Valle-de-la-Gatineau"
 2484 "Pontiac"
 2485 "Tmiscamingue"
 2486 "Rouyn-Noranda"
 2487 "Abitibi-Ouest"
 2488 "Abitibi"
 2489 "La Valle-de-l'Or"
 2490 "La Tuque"
 2491 "Le Domaine-du-Roy"
 2492 "Maria-Chapdelaine"
 2493 "Lac-Saint-Jean-Est"
 2494 "Le Saguenay-et-son-Fjord"
 2495 "La Haute-Cte-Nord"
 2496 "Manicouagan"
 2497 "Sept-Rivires--Caniapiscau"
 2498 "Minganie--Basse-Cte-Nord"
 2499 "Nord-du-Qubec"
 3501 "Stormont, Dundas and Glengarry"
 3502 "Prescott and Russell"
 3506 "Ottawa"
 3507 "Leeds and Grenville"
 3509 "Lanark"
 3510 "Frontenac"
 3511 "Lennox and Addington"
 3512 "Hastings"
 3513 "Prince Edward"
 3514 "Northumberland"
 3515 "Peterborough"
 3516 "Kawartha Lakes"
 3518 "Durham"
 3519 "York"
 3520 "Toronto"
 3521 "Peel"
 3522 "Dufferin"
 3523 "Wellington"
 3524 "Halton"
 3525 "Hamilton"
 3526 "Niagara"
 3528 "Haldimand-Norfolk"
 3529 "Brant"
 3530 "Waterloo"
 3531 "Perth"
 3532 "Oxford"
 3534 "Elgin"
 3536 "Chatham-Kent"
 3537 "Essex"
 3538 "Lambton"
 3539 "Middlesex"
 3540 "Huron"
 3541 "Bruce"
 3542 "Grey"
 3543 "Simcoe"
 3544 "Muskoka"
 3546 "Haliburton"
 3547 "Renfrew"
 3548 "Nipissing"
 3549 "Parry Sound"
 3551 "Manitoulin"
 3552 "Sudbury"
 3553 "Greater Sudbury / Grand Sudbury"
 3554 "Timiskaming"
 3556 "Cochrane"
 3557 "Algoma"
 3558 "Thunder Bay"
 3559 "Rainy River"
 3560 "Kenora"
 4601 "Division No.  1"
 4602 "Division No.  2"
 4603 "Division No.  3"
 4604 "Division No.  4"
 4605 "Division No.  5"
 4606 "Division No.  6"
 4607 "Division No.  7"
 4608 "Division No.  8"
 4609 "Division No.  9"
 4610 "Division No. 10"
 4611 "Division No. 11"
 4612 "Division No. 12"
 4613 "Division No. 13"
 4614 "Division No. 14"
 4615 "Division No. 15"
 4616 "Division No. 16"
 4617 "Division No. 17"
 4618 "Division No. 18"
 4619 "Division No. 19"
 4620 "Division No. 20"
 4621 "Division No. 21"
 4622 "Division No. 22"
 4623 "Division No. 23"
 4701 "Division No.  1"
 4702 "Division No.  2"
 4703 "Division No.  3"
 4704 "Division No.  4"
 4705 "Division No.  5"
 4706 "Division No.  6"
 4707 "Division No.  7"
 4708 "Division No.  8"
 4709 "Division No.  9"
 4710 "Division No. 10"
 4711 "Division No. 11"
 4712 "Division No. 12"
 4713 "Division No. 13"
 4714 "Division No. 14"
 4715 "Division No. 15"
 4716 "Division No. 16"
 4717 "Division No. 17"
 4718 "Division No. 18"
 4801 "Division No.  1"
 4802 "Division No.  2"
 4803 "Division No.  3"
 4804 "Division No.  4"
 4805 "Division No.  5"
 4806 "Division No.  6"
 4807 "Division No.  7"
 4808 "Division No.  8"
 4809 "Division No.  9"
 4810 "Division No. 10"
 4811 "Division No. 11"
 4812 "Division No. 12"
 4813 "Division No. 13"
 4814 "Division No. 14"
 4815 "Division No. 15"
 4816 "Division No. 16"
 4817 "Division No. 17"
 4818 "Division No. 18"
 4819 "Division No. 19"
 5901 "East Kootenay"
 5903 "Central Kootenay"
 5905 "Kootenay Boundary"
 5907 "Okanagan-Similkameen"
 5909 "Fraser Valley"
 5915 "Greater Vancouver"
 5917 "Capital"
 5919 "Cowichan Valley"
 5921 "Nanaimo"
 5923 "Alberni-Clayoquot"
 5925 "Comox-Strathcona"
 5927 "Powell River"
 5929 "Sunshine Coast"
 5931 "Squamish-Lillooet"
 5933 "Thompson-Nicola"
 5935 "Central Okanagan"
 5937 "North Okanagan"
 5939 "Columbia-Shuswap"
 5941 "Cariboo"
 5943 "Mount Waddington"
 5945 "Central Coast"
 5947 "Skeena-Queen Charlotte"
 5949 "Kitimat-Stikine"
 5951 "Bulkley-Nechako"
 5953 "Fraser-Fort George"
 5955 "Peace River"
 5957 "Stikine"
 5959 "Northern Rockies"
 6001 "Yukon"
 6106 "Fort Smith"
 6107 "Inuvik"
 6204 "Baffin"
 6205 "Keewatin"
 6208 "Kitikmeot"
 /
 CSDUID
 /
 CSDNAME
 /
 CSDTYPE
 "C  " "City / Cit"
 "CC " "Chartered Community"
 "C " "Cit"
 "CG " "Community government"
 "CM " "County (municipality)"
 "CN " "Crown colony / Colonie de la couronne"
 "COM" "Community"
 "CT " "Canton (municipalit de)"
 "CU " "Cantons unis (municipalit de)"
 "CY " "City"
 "DM " "District Municipality"
 "HAM" "Hamlet"
 "ID " "Improvement District"
 "IGD" "Indian Government District"
 "IM " "Island Municipality"
 "IRI" "Indian reserve / Rserve Indienne"
 "LGD" "Local Government District"
 "LOT" "Township and Royalty"
 "M  " "Municipality / Municipalit"
 "MD " "Municipal District"
 "M " "Municipalit"
 "MU " "Municipality"
 "NH " "Northern Hamlet"
 "NL " "Nisga's Land"
 "NO " "Unorganized / Non organis"
 "NV " "Northern Village"
 "NVL" "Nisga's Village"
 "P  " "Parish / Paroisse (municipalit de)"
 "PE " "Paroisse (municipalit de)"
 "RCR" "Rural Community / Communaut rurale"
 "RDA" "Regional district electoral area"
 "RG " "Region"
 "RGM" "Regional Municipality"
 "RM " "Rural Municipality"
 "RV " "Resort Village"
 "SA " "Special area"
 "SC " "Subdivision of County Municipality / Subdivision municipalit de comt"
 "S-" "Indian Settlement / tablissement Indien"
 "S " "Settlement / tablissement"
 "SET" "Settlement"
 "SM " "Specialized Municipality"
 "SNO" "Subdivision of Unorganized / Subdivision non organise"
 "SV " "Summer Village"
 "T  " "Town"
 "TC " "Terres rserves aux Cris"
 "TI " "Terre inuite"
 "TK " "Terres rserves aux Naskapis"
 "TL " "Teslin Land"
 "TP " "Township"
 "UNO" "Unorganized"
 "TV " "Town / Ville"
 "V  " "Ville"
 "VC " "Village cri"
 "VK " "Village naskapi"
 "VL " "Village"
 "VN " "Village nordique"
 /
 ccscode
 /
 SAC
 000 "Territories / Territoires"
 001 "St. John's"
 005 "Bay Roberts"
 010 "Grand Falls-Windsor"
 015 "Corner Brook"
 105 "Charlottetown"
 110 "Summerside"
 205 "Halifax"
 210 "Kentville"
 215 "Truro"
 220 "New Glasgow"
 225 "Cape Breton"
 305 "Moncton"
 310 "Saint John"
 320 "Fredericton"
 328 "Bathurst"
 329 "Miramichi"
 330 "Campbellton"
 335 "Edmundston"
 403 "Matane"
 404 "Rimouski"
 405 "Rivire-du-Loup"
 406 "Baie-Comeau"
 408 "Saguenay"
 410 "Alma"
 411 "Dolbeau-Mistassini"
 412 "Sept-les"
 421 "Qubec"
 428 "Saint-Georges"
 430 "Thetford Mines"
 433 "Sherbrooke"
 437 "Cowansville"
 440 "Victoriaville"
 442 "Trois-Rivires"
 444 "Shawinigan"
 446 "La Tuque"
 447 "Drummondville"
 450 "Granby"
 452 "Saint-Hyacinthe"
 454 "Sorel-Tracy"
 456 "Joliette"
 459 "Saint-Jean-sur-Richelieu"
 462 "Montral"
 465 "Salaberry-de-Valleyfield"
 468 "Lachute"
 480 "Val-d'Or"
 481 "Amos"
 485 "Rouyn-Noranda"
 501 "Cornwall"
 502 "Hawkesbury"
 505 "Ottawa - Gatineau"
 512 "Brockville"
 515 "Pembroke"
 516 "Petawawa"
 521 "Kingston"
 522 "Belleville"
 527 "Cobourg"
 528 "Port Hope"
 529 "Peterborough"
 530 "Kawartha Lakes"
 531 "Centre Wellington"
 532 "Oshawa"
 533 "Ingersoll"
 535 "Toronto"
 537 "Hamilton"
 539 "St. Catharines - Niagara"
 541 "Kitchener"
 543 "Brantford"
 544 "Woodstock"
 546 "Tillsonburg"
 547 "Norfolk"
 550 "Guelph"
 553 "Stratford"
 555 "London"
 556 "Chatham-Kent"
 557 "Leamington"
 559 "Windsor"
 562 "Sarnia"
 566 "Owen Sound"
 567 "Collingwood"
 568 "Barrie"
 569 "Orillia"
 571 "Midland"
 575 "North Bay"
 580 "Greater Sudbury / Grand Sudbury"
 582 "Elliot Lake"
 584 "Temiskaming Shores"
 586 "Timmins"
 590 "Sault Ste. Marie"
 595 "Thunder Bay"
 598 "Kenora"
 602 "Winnipeg"
 607 "Portage la Prairie"
 610 "Brandon"
 640 "Thompson"
 705 "Regina"
 710 "Yorkton"
 715 "Moose Jaw"
 720 "Swift Current"
 725 "Saskatoon"
 735 "North Battleford"
 745 "Prince Albert"
 750 "Estevan"
 805 "Medicine Hat"
 806 "Brooks"
 810 "Lethbridge"
 820 "Okotoks"
 825 "Calgary"
 828 "Canmore"
 830 "Red Deer"
 833 "Camrose"
 835 "Edmonton"
 840 "Lloydminster"
 845 "Cold Lake"
 850 "Grande Prairie"
 860 "Wood Buffalo"
 865 "Wetaskiwin"
 905 "Cranbrook"
 913 "Penticton"
 915 "Kelowna"
 918 "Vernon"
 920 "Salmon Arm"
 925 "Kamloops"
 930 "Chilliwack"
 932 "Abbotsford"
 933 "Vancouver"
 934 "Squamish"
 935 "Victoria"
 937 "Duncan"
 938 "Nanaimo"
 939 "Parksville"
 940 "Port Alberni"
 943 "Courtenay"
 944 "Campbell River"
 945 "Powell River"
 950 "Williams Lake"
 952 "Quesnel"
 955 "Prince Rupert"
 960 "Kitimat"
 965 "Terrace"
 970 "Prince George"
 975 "Dawson Creek"
 977 "Fort St. John"
 990 "Whitehorse"
 995 "Yellowknife"
 996 "Strongly influenced zone / Fortement influence zone"
 997 "Moderately influenced zone / Moyennement influence zone"
 998 "Weakly influenced zone / Faiblement influence zone"
 999 "Not influenced zone / Non influence zone"
 /
 sacTYPE
 1 "Census metropolitan area"
 2 "Tracted census agglomeration"
 3 "Non-tracted census agglomeration"
 4 "Strongly influenced zone"
 5 "Moderately influenced zone"
 6 "Weakly influenced zone"
 7 "Not influenced zone"
 8 "Territories"
 /
 ctname
 /
 ER
 /
 DPL
 /
 fed03uid
 62001 "Nunavut"
 60001 "Yukon"
 59022 "Prince George - Peace River"
 24046 "Abitibi - Baie-James - Nunavik - Eeyou"
 10004 "Labrador"
 47003 "Desneth - Missinippi - Churchill River / Desneth - Missinippi - Rivire Churchill"
 59004 "Cariboo - Prince George"
 10003 "Humber - St. Barbe - Baie Verte"
 24039 "Manicouagan"
 48025 "Westlock - St. Paul"
 59010 "Kamloops - Thompson - Cariboo"
 48024 "Vegreville - Wainwright"
 10001 "Avalon"
 59036 "West Vancouver - Sunshine Coast - Sea to Sky Country"
 59005 "Chilliwack - Fraser Canyon"
 48017 "Edmonton - Spruce Grove"
 35092 "Timmins - James Bay / Timmins - Baie James"
 10006 "St. John's East / St. John's-Est"
 48016 "Edmonton - Sherwood Park"
 48015 "Edmonton - St. Albert"
 48026 "Wetaskiwin"
 48014 "Edmonton - Leduc"
 59014 "Nanaimo - Alberni"
 48027 "Wild Rose"
 47001 "Battlefords - Lloydminster"
 59018 "Okanagan - Shuswap"
 24016 "Chicoutimi - Le Fjord"
 59020 "Okanagan - Coquihalla"
 59007 "Pitt Meadows - Maple Ridge - Mission"
 48023 "Red Deer"
 59015 "Nanaimo - Cowichan"
 47006 "Prince Albert"
 59019 "North Vancouver"
 47011 "Saskatoon - Wanuskewin"
 59029 "Vancouver Centre / Vancouver-Centre"
 59032 "Vancouver Kingsway"
 59006 "Delta - Richmond East / Delta - Richmond-Est"
 59017 "New Westminster - Coquitlam"
 59003 "Burnaby - New Westminster"
 59024 "Saanich - Gulf Islands"
 59028 "Surrey North / Surrey-Nord"
 59009 "Fleetwood - Port Kells"
 59013 "Langley"
 59011 "Kelowna - Lake Country"
 59001 "Abbotsford"
 48009 "Calgary West / Calgary-Ouest"
 48004 "Calgary Northeast / Calgary-Nord-Est"
 47014 "Yorkton - Melville"
 48003 "Calgary Centre-North / Calgary-Centre-Nord"
 48002 "Calgary East / Calgary-Est"
 46004 "Dauphin - Swan River - Marquette"
 48008 "Calgary Southwest / Calgary-Sud-Ouest"
 48007 "Calgary Southeast / Calgary-Sud-Est"
 46010 "Selkirk - Interlake"
 48021 "Medicine Hat"
 24041 "Haute-Gaspsie - La Mitis - Matane - Matapdia"
 47008 "Regina - Qu'Appelle"
 12010 "Sydney - Victoria"
 24014 "Montmorency - Charlevoix - Haute-Cte-Nord"
 48019 "Lethbridge"
 12001 "Cape Breton - Canso"
 35091 "Thunder Bay - Superior North / Thunder Bay - Superior-Nord"
 13006 "Miramichi"
 47005 "Palliser"
 13005 "Madawaska - Restigouche"
 47013 "Wascana"
 47012 "Souris - Moose Mountain"
 24026 "Jonquire - Alma"
 11004 "Malpeque"
 24001 "Abitibi - Tmiscamingue"
 11002 "Charlottetown"
 13002 "Beausjour"
 46008 "Provencher"
 13010 "Tobique - Mactaquac"
 35002 "Algoma - Manitoulin - Kapuskasing"
 46007 "Portage - Lisgar"
 13007 "Moncton - Riverview - Dieppe"
 13004 "Fundy Royal"
 46002 "Charleswood - St. James - Assiniboia"
 35090 "Thunder Bay - Rainy River"
 46005 "Elmwood - Transcona"
 46011 "Winnipeg Centre / Winnipeg-Centre"
 46009 "Saint Boniface / Saint-Boniface"
 13003 "Fredericton"
 46014 "Winnipeg South Centre / Winnipeg-Centre-Sud"
 24051 "Portneuf - Jacques-Cartier"
 12006 "Kings - Hants"
 12008 "Sackville - Eastern Shore"
 24034 "Lvis - Bellechasse"
 24050 "Pontiac"
 24007 "Beauport - Limoilou"
 24013 "Charlesbourg - Haute-Saint-Charles"
 12005 "Halifax West / Halifax-Ouest"
 12003 "Dartmouth - Cole Harbour"
 13009 "Saint John"
 24052 "Qubec"
 24037 "Louis-Hbert"
 24036 "Lotbinire - Chutes-de-la-Chaudire"
 35056 "Nickel Belt"
 24042 "Mgantic - L'rable"
 35057 "Nipissing - Timiskaming"
 24017 "Compton - Stanstead"
 24074 "Verchres - Les Patriotes"
 24063 "Saint-Hyacinthe - Bagot"
 24004 "Argenteuil - Papineau - Mirabel"
 24059 "Rivire-du-Nord"
 24070 "Sherbrooke"
 35079 "Sault Ste. Marie"
 24071 "Terrebonne - Blainville"
 24010 "Brome - Missisquoi"
 24028 "La Pointe-de-l'le"
 24022 "Honor Mercier"
 24003 "Alfred-Pellan"
 24040 "Marc-Aurle-Fortin"
 24062 "Saint-Bruno - Saint-Hubert"
 24067 "Saint-Lonard - Saint-Michel"
 24057 "Rivire-des-Mille-les"
 24032 "Laval"
 24002 "Ahuntsic"
 24048 "Papineau"
 24061 "Rosemont - La Petite-Patrie"
 24065 "Saint-Lambert"
 24033 "Laval - Les les"
 24044 "Mont-Royal / Mount Royal"
 24011 "Brossard - La Prairie"
 24024 "Jeanne-Le Ber"
 24045 "Notre-Dame-de-Grce - Lachine"
 35074 "Renfrew - Nipissing - Pembroke"
 24073 "Vaudreuil-Soulanges"
 24006 "Beauharnois - Salaberry"
 35088 "Sudbury"
 24020 "Gatineau"
 35069 "Parry Sound - Muskoka"
 35063 "Ottawa - Orlans"
 35065 "Ottawa - Vanier"
 24023 "Hull - Aylmer"
 35012 "Carleton - Mississippi Mills"
 35062 "Ottawa Centre / Ottawa-Centre"
 35052 "Nepean - Carleton"
 35073 "Prince Edward - Hastings"
 35026 "Bruce - Grey - Owen Sound"
 35036 "Kingston and the Islands / Kingston et les les"
 35086 "Simcoe North / Simcoe-Nord"
 35085 "Simcoe - Grey"
 35058 "Northumberland - Quinte West"
 35104 "York - Simcoe"
 35004 "Barrie"
 35014 "Durham"
 35034 "Huron - Bruce"
 35059 "Oak Ridges - Markham"
 35053 "Newmarket - Aurora"
 35096 "Vaughan"
 35045 "Markham - Unionville"
 35083 "Scarborough - Rouge River"
 35070 "Perth - Wellington"
 35080 "Scarborough - Agincourt"
 35100 "Willowdale"
 35016 "Don Valley East / Don Valley-Est"
 35006 "Bramalea - Gore - Malton"
 35081 "Scarborough Centre / Scarborough-Centre"
 35103 "York Centre / York-Centre"
 35098 "Wellington - Halton Hills"
 35019 "Eglinton - Lawrence"
 35007 "Brampton - Springdale"
 35077 "St. Paul's"
 35094 "Toronto - Danforth"
 35093 "Toronto Centre / Toronto-Centre"
 35015 "Davenport"
 35022 "Etobicoke Centre / Etobicoke-Centre"
 35008 "Brampton West / Brampton-Ouest"
 35023 "Etobicoke - Lakeshore"
 35047 "Mississauga - Brampton South / Mississauga - Brampton-Sud"
 35048 "Mississauga East - Cooksville / Mississauga-Est - Cooksville"
 35038 "Kitchener - Conestoga"
 35060 "Oakville"
 35027 "Guelph"
 35003 "Ancaster - Dundas - Flamborough - Westdale"
 35037 "Kitchener Centre / Kitchener-Centre"
 35054 "Niagara Falls"
 35031 "Hamilton Centre / Hamilton-Centre"
 35032 "Hamilton East - Stoney Creek / Hamilton-Est - Stoney Creek"
 35055 "Niagara West - Glanbrook / Niagara-Ouest - Glanbrook"
 35067 "Oxford"
 35009 "Brant"
 35097 "Welland"
 35028 "Haldimand - Norfolk"
 35046 "Lambton - Kent - Middlesex"
 35043 "London North Centre / London-Centre-Nord"
 35044 "London West / London-Ouest"
 35013 "Chatham-Kent - Essex"
 35021 "Essex"
 35102 "Windsor West / Windsor-Ouest"
 46013 "Winnipeg South / Winnipeg-Sud"
 24027 "Lac-Saint-Louis"
 35072 "Pickering - Scarborough East / Pickering - Scarborough-Est"
 59031 "Vancouver Island North / le de Vancouver-Nord"
 10005 "Random - Burin - St. George's"
 48011 "Edmonton - Mill Woods - Beaumont"
 59030 "Vancouver East / Vancouver-Est"
 59035 "Victoria"
 47004 "Cypress Hills - Grasslands"
 24058 "Montmagny - L'Islet - Kamouraska - Rivire-du-Loup"
 24030 "Laurentides - Labelle"
 24055 "Richmond - Arthabaska"
 24012 "Chambly - Borduas"
 24047 "Outremont"
 24015 "Chteauguay - Saint-Constant"
 35071 "Peterborough"
 35075 "Richmond Hill"
 35051 "Mississauga - Streetsville"
 10002 "Bonavista - Gander - Grand Falls - Windsor"
 10007 "St. John's South - Mount Pearl / St. John's-Sud - Mount Pearl"
 11003 "Egmont"
 12004 "Halifax"
 12007 "Cumberland - Colchester - Musquodoboit Valley"
 12011 "West Nova / Nova-Ouest"
 13008 "New Brunswick Southwest / Nouveau-Brunswick-Sud-Ouest"
 24008 "Berthier - Maskinong"
 24009 "Bourassa"
 24018 "Drummond"
 11001 "Cardigan"
 12009 "South Shore - St. Margaret's"
 12002 "Central Nova / Nova-Centre"
 13001 "Acadie - Bathurst"
 24056 "Rimouski-Neigette - Tmiscouata - Les Basques"
 24064 "Saint-Jean"
 24069 "Shefford"
 24075 "Westmount - Ville-Marie"
 24005 "Beauce"
 24031 "Laurier - Sainte-Marie"
 24043 "Montcalm"
 35041 "Leeds - Grenville"
 35050 "Mississauga South / Mississauga-Sud"
 35064 "Ottawa South / Ottawa-Sud"
 35076 "St. Catharines"
 35011 "Cambridge"
 35025 "Glengarry - Prescott - Russell"
 35101 "Windsor - Tecumseh"
 35106 "York West / York-Ouest"
 35029 "Haliburton - Kawartha Lakes - Brock"
 46001 "Brandon - Souris"
 47009 "Saskatoon - Humboldt"
 48001 "Fort McMurray - Athabasca"
 48005 "Calgary - Nose Hill"
 48012 "Edmonton Centre / Edmonton-Centre"
 48018 "Edmonton - Strathcona"
 59023 "Richmond"
 59025 "Skeena - Bulkley Valley"
 59026 "British Columbia Southern Interior / Colombie-Britannique-Southern Interior"
 59034 "Vancouver South / Vancouver-Sud"
 24019 "Gaspsie - les-de-la-Madeleine"
 24021 "Hochelaga"
 24025 "Joliette"
 24029 "LaSalle - mard"
 24035 "Longueuil - Pierre-Boucher"
 24038 "Louis-Saint-Laurent"
 24049 "Pierrefonds - Dollard"
 24053 "Repentigny"
 24054 "Bas-Richelieu - Nicolet - Bcancour"
 24060 "Roberval - Lac-Saint-Jean"
 24066 "Saint-Laurent - Cartierville"
 24068 "Saint-Maurice - Champlain"
 24072 "Trois-Rivires"
 35001 "Ajax - Pickering"
 35005 "Beaches - East York"
 35010 "Burlington"
 35017 "Don Valley West / Don Valley-Ouest"
 35018 "Dufferin - Caledon"
 35020 "Elgin - Middlesex - London"
 35024 "Etobicoke North / Etobicoke-Nord"
 35030 "Halton"
 35033 "Hamilton Mountain"
 35035 "Kenora"
 35039 "Kitchener - Waterloo"
 35040 "Lanark - Frontenac - Lennox and Addington"
 35042 "London - Fanshawe"
 35049 "Mississauga - Erindale"
 35061 "Oshawa"
 35066 "Ottawa West - Nepean / Ottawa-Ouest - Nepean"
 35068 "Parkdale - High Park"
 35078 "Sarnia - Lambton"
 35082 "Scarborough - Guildwood"
 35084 "Scarborough Southwest / Scarborough-Sud-Ouest"
 35087 "Stormont - Dundas - South Glengarry"
 35089 "Thornhill"
 35095 "Trinity - Spadina"
 35099 "Whitby - Oshawa"
 35105 "York South - Weston / York-Sud - Weston"
 46003 "Churchill"
 46006 "Kildonan - St. Paul"
 46012 "Winnipeg North / Winnipeg-Nord"
 47002 "Blackstrap"
 47007 "Regina - Lumsden - Lake Centre"
 47010 "Saskatoon - Rosetown - Biggar"
 48006 "Calgary Centre / Calgary-Centre"
 48010 "Crowfoot"
 48013 "Edmonton East / Edmonton-Est"
 48020 "Macleod"
 48022 "Peace River"
 48028 "Yellowhead"
 59002 "Burnaby - Douglas"
 59008 "Esquimalt - Juan de Fuca"
 59012 "Kootenay - Columbia"
 59016 "Newton - North Delta / Newton - Delta-Nord"
 59021 "Port Moody - Westwood - Port Coquitlam"
 59027 "South Surrey - White Rock - Cloverdale / Surrey-Sud - White Rock - Cloverdale"
 59033 "Vancouver Quadra"
 61001 "Western Arctic"
 /
 PCRACODE
    0 "Not urban area: postal code linked to dissemination area only (REPPOINT=3)"
 9910 "Not an urban area: Newfoundland/Labrador"
 9911 "Not an urban area: Prince Edward Island"
 9912 "Not an urban area: Nova Scotia"
 9913 "Not an urban area: New Brunswick"
 9924 "Not an urban area: Quebec"
 9935 "Not an urban area: Ontario"
 9946 "Not an urban area: Manitoba"
 9947 "Not an urban area: Saskatchewan"
 9948 "Not an urban area: Alberta"
 9959 "Not an urban area: British Columbia"
 9960 "Not an urban area: Yukon"
 9961 "Not an urban area: Northwest Territories"
 9962 "Not an urban area: Nunavut"
 /
 PCRATYPE
 0 "Rural Area"
 1 "Urban Core"
 2 "Urban Fringe"
 4 "Urban Area outside CMAs/CAs"
 6 "Secondary urban core"
 9 "Postal code linked to dissemination area only (REPPOINT=3)"
 /
 dauid
 /
 blockcod
 0 "Postal code linked to dissemination area only (REPPOINT=3)"
 /
 blockuid
 /
 reppoint
 1 "Block-face"
 2 "Dissemination block"
 3 "Dissemination area"
 /
 latitude
 /
 longitud
 /
 SLI
 0 "Additional record for postal code"
 1 "Best or only record for postal code"
 /
 PCTYPE
 1 "Street address with letter carrier service"
 2 "Street address with route service"
 3 "Post office box"
 4 "Route service"
 5 "General delivery"
 0 "Unknown"
 /
 COMMNAME
 /
 DMT HDMT
 "A" "Delivery to Block Face Address"
 "B" "Delivery to an apartment building"
 "E" "Delivery to a business building"
 "G" "Delivery to a large volume receiver"
 "H" "Delivery via a rural route"
 "J" "General delivery"
 "K" "Delivery to a post office box (not a CMB)"
 "M" "Delivery to a large volume receiver (post office box)"
 "T" "Delivery via a suburban service"
 "W" "Rural postal codes (second digit of postal code is '0')"
 "X" "Delivery via a mobile route"
 "Z" "Postal code is retired (no further delivery to this code)"
 /
 BRTHDATE
 19830401 "Postal code created before April, 1983"
 /
 RTRDDATE
 19830401 "Postal code retired before April, 1983"
 19000001 "Active postal code"
 /
 PO
 0 "Coded to area serviced by the postal code"
 1 "Coded to a post office or other postal installation"
 2 "Unknown"
 /
 QI
 "AAA" "Highest quality link"
 "AAB" "... - see QI1, QI2, and QI3"
 "AAC" "... - see QI1, QI2, and QI3"
 "AAN" "... - see QI1, QI2, and QI3"
 "ABA" "... - see QI1, QI2, and QI3"
 "ABB" "... - see QI1, QI2, and QI3"
 "ABC" "... - see QI1, QI2, and QI3"
 "ABN" "... - see QI1, QI2, and QI3"
 "ACA" "... - see QI1, QI2, and QI3"
 "ACB" "... - see QI1, QI2, and QI3"
 "ACC" "... - see QI1, QI2, and QI3"
 "ACN" "... - see QI1, QI2, and QI3"
 "ANN" "... - see QI1, QI2, and QI3"
 "BAA" "... - see QI1, QI2, and QI3"
 "BAB" "... - see QI1, QI2, and QI3"
 "BAC" "... - see QI1, QI2, and QI3"
 "BAN" "... - see QI1, QI2, and QI3"
 "BBA" "... - see QI1, QI2, and QI3"
 "BBB" "... - see QI1, QI2, and QI3"
 "BBC" "... - see QI1, QI2, and QI3"
 "BBN" "... - see QI1, QI2, and QI3"
 "BCA" "... - see QI1, QI2, and QI3"
 "BCB" "... - see QI1, QI2, and QI3"
 "BCC" "... - see QI1, QI2, and QI3"
 "BCN" "... - see QI1, QI2, and QI3"
 "BNN" "... - see QI1, QI2, and QI3"
 "CAA" "... - see QI1, QI2, and QI3"
 "CAB" "... - see QI1, QI2, and QI3"
 "CAC" "... - see QI1, QI2, and QI3"
 "CAN" "... - see QI1, QI2, and QI3"
 "CBA" "... - see QI1, QI2, and QI3"
 "CBB" "... - see QI1, QI2, and QI3"
 "CBC" "... - see QI1, QI2, and QI3"
 "CBN" "... - see QI1, QI2, and QI3"
 "CCA" "... - see QI1, QI2, and QI3"
 "CCB" "... - see QI1, QI2, and QI3"
 "CCC" "... - see QI1, QI2, and QI3"
 "CCN" "... - see QI1, QI2, and QI3"
 "NNN" "Completely unknown"
 /
 QI1
 "A" "Good, verifiable geocoding, search area verified by more than one source"
 "B" "Good, search area based on 2006 Census data"
 "C" "Satisfactory approximation based on place name match to CSD alone"
 "N" "Unknown"
 /
 QI2
 "A" "Good, match on street name, type, and direction"
 "B" "Good, but match only on street name and type"
 "C" "Satisfactory match on street name only or street name and direction"
 "N" "Unknown"
 /
 QI3
 "A" "Good, if the parity was matched on both address on the Spatial Data Infrastructure"
 "B" "Good, but the parity was matched on one address only on the Spatial Data Infrastructure"
 "C" "Satisfactory, if the parity was not matched but the ranges overlap"
 "N" "No match"
 /
 SOURCE
 1 "Automated geocoding directly to 2006 geographic areas"
 2 "Geocoding using 2006 census response"
 3 "Converted from geocoding done to 2001 geographic areas"
 4 "Manually geocoded"
 /
 new_er
 1010 "Avalon Peninsula"
 1020 "South Coast - Burin Peninsula"
 1030 "West Coast - Northern Peninsula - Labrador"
 1040 "Notre Dame - Central Bonavista Bay"
 1110 "Prince Edward Island"
 1210 "Cape Breton"
 1220 "North Shore"
 1230 "Annapolis Valley"
 1240 "Southern"
 1250 "Halifax"
 1310 "Campbellton - Miramichi"
 1320 "Moncton - Richibucto"
 1330 "Saint John - St. Stephen"
 1340 "Fredericton - Oromocto"
 1350 "Edmundston - Woodstock"
 2410 "Gaspsie - les-de-la-Madeleine"
 2415 "Bas-Saint-Laurent"
 2420 "Qubec"
 2425 "Chaudire-Appalaches"
 2430 "Estrie"
 2433 "Centre-du-Qubec"
 2435 "Montrgie"
 2440 "Montral"
 2445 "Laval"
 2450 "Lanaudire"
 2455 "Laurentides"
 2460 "Outaouais"
 2465 "Abitibi-Tmiscamingue"
 2470 "Mauricie"
 2475 "Saguenay - Lac-Saint-Jean"
 2480 "Cte-Nord"
 2490 "Nord-du-Qubec"
 3510 "Ottawa"
 3515 "Kingston - Pembroke"
 3520 "Muskoka - Kawarthas"
 3530 "Toronto"
 3540 "Kitchener - Waterloo - Barrie"
 3550 "Hamilton - Niagara Peninsula"
 3560 "London"
 3570 "Windsor - Sarnia"
 3580 "Stratford - Bruce Peninsula"
 3590 "Northeast"
 3595 "Northwest"
 4610 "Southeast"
 4620 "South Central"
 4630 "Southwest"
 4640 "North Central"
 4650 "Winnipeg"
 4660 "Interlake"
 4670 "Parklands"
 4680 "North"
 4710 "Regina"
 4720 "Swift Current - Moose Jaw"
 4730 "Saskatoon - Biggar"
 4740 "Yorkton - Melville"
 4750 "Prince Albert"
 4760 "Northern"
 4810 "Lethbridge - Medicine Hat"
 4820 "Camrose - Drumheller"
 4830 "Calgary"
 4840 "Banff - Jasper - Rocky Mountain House"
 4850 "Red Deer"
 4860 "Edmonton"
 4870 "Athabasca - Grande Prairie - Peace River"
 4880 "Wood Buffalo - Cold Lake"
 5910 "Vancouver Island and Coast"
 5920 "Lower Mainland - Southwest"
 5930 "Thompson - Okanagan"
 5940 "Kootenay"
 5950 "Cariboo"
 5960 "North Coast"
 5970 "Nechako"
 5980 "Northeast"
 6010 "Yukon"
 6110 "Northwest Territories"
 6210 "Nunavut"
 /
 new_dpl
 109910 "Not a designated place: Newfoundland/Labrador"
 119911 "Not a designated place: Prince Edward Island"
 129912 "Not a designated place: Nova Scotia"
 139913 "Not a designated place: New Brunswick"
 249924 "Not a designated place: Quebec"
 359935 "Not a designated place: Ontario"
 469946 "Not a designated place: Manitoba"
 479947 "Not a designated place: Saskatchewan"
 489948 "Not a designated place: Alberta"
 599959 "Not a designated place: British Columbia"
 609960 "Not a designated place: Yukon"
 619961 "Not a designated place: Northwest Territories"
 629962 "Not a designated place: Nunavut"
 100100 "Little St. Lawrence"
 100101 "Patrick's Cove-Angels Cove"
 100102 "Jean de Baie"
 100103 "Spanish Room"
 100104 "Beau Bois"
 100105 "Epworth-Great Salmonier"
 100106 "Petit Forte"
 100107 "Southeast Bight"
 100108 "Harbour Mille-Little Harbour East"
 100109 "St. Joseph's Cove-St. Veronica's"
 100110 "Swift Current"
 100111 "Garden Cove"
 100112 "Grand Bruit"
 100113 "La Poile"
 100114 "Grand Beach"
 100115 "Diamond Cove"
 100117 "Cape Ray"
 100118 "Fox Roost-Margaree"
 100119 "St. Andrews"
 100120 "Benoits Siding"
 100121 "Great Codroy"
 100122 "O'Regan's Central"
 100123 "Searston"
 100124 "Tompkins"
 100125 "Upper Ferry"
 100126 "McCallum"
 100127 "Franois"
 100128 "Grey River"
 100129 "Bay St. George South"
 100130 "Flat Bay"
 100131 "St. Teresa"
 100132 "Black Duck Brook and Winterhouse"
 100133 "Campbells Creek part A"
 100134 "Fox Island River-Point au Mal"
 100135 "Piccadilly Slant-Abrahams Cove"
 100136 "Ship Cove-Lower Cove-Jerry's Nose"
 100137 "West Bay"
 100138 "Barachois Brook"
 100139 "Mattis Point"
 100140 "Black Duck"
 100141 "Mainland"
 100142 "Sheaves Cove"
 100143 "Three Rock Cove"
 100144 "Black Duck Cove, Northern Peninsula"
 100145 "Brig Bay"
 100146 "Forresters Point"
 100147 "Pidgeon Cove-St. Barbe"
 100148 "Plum Point"
 100149 "Reefs Harbour-Shoal Cove West-New Ferolle"
 100150 "Goobies part A"
 100151 "Brown's Arm"
 100152 "Laurenceton"
 100153 "Norris Arm North"
 100154 "Phillips Head"
 100155 "Cottrell's Cove"
 100156 "Fortune Harbour"
 100157 "Pleasantview"
 100158 "Stanhope"
 100159 "Gander Bay North"
 100160 "Horwood"
 100161 "Loon Bay"
 100163 "Stoneville"
 100164 "Boyd's Cove"
 100165 "Aspen Cove"
 100166 "Gander Bay South"
 100167 "Main Point-Davidsville"
 100168 "Noggin Cove"
 100169 "Bridgeport"
 100170 "Chanceport"
 100171 "Cobbs Arm"
 100172 "Fairbanks-Hillgrade"
 100173 "Herring Neck"
 100174 "Indian Cove"
 100175 "Moreton's Harbour"
 100176 "Newville"
 100177 "Port Albert"
 100178 "Purcell's Harbour"
 100179 "Tizzard's Harbour"
 100180 "Valley Pond"
 100181 "Virgin Arm-Carter's Cove"
 100182 "Merritt's Harbour"
 100183 "Buchans Junction"
 100184 "Bunyan's Cove"
 100185 "Charlottetown, B. Bay"
 100186 "Benton"
 100187 "Cape Freels North"
 100188 "Deadman's Bay"
 100189 "Harry's Harbour"
 100190 "Jackson's Cove-Langdon's Cove-Silverdale"
 100191 "Smith's Harbour"
 100192 "St. Patricks"
 100193 "Snook's Arm"
 100194 "Humber Village"
 100195 "Little Rapids"
 100196 "St. Judes"
 100197 "Sheppardville"
 100198 "Rattling Brook"
 100199 "Croque"
 100200 "St. Juliens"
 100201 "Great Brehat"
 100202 "St. Anthony Bight"
 100205 "Pynns Brook"
 100206 "Beaches"
 100207 "Sop's Arm"
 100208 "Wild Cove, White Bay"
 100209 "Portland Creek"
 100210 "Bartletts Harbour"
 100211 "Castor River North"
 100213 "Ship Cove, Northern Peninsula"
 100214 "Bear Cove, Northern Peninsula"
 100215 "Green Island Brook"
 100216 "Nameless Cove"
 100217 "Bellevue"
 100218 "Bellevue Beach"
 100219 "Blaketown"
 100220 "Dildo"
 100221 "Fairhaven"
 100222 "Green's Harbour"
 100223 "Hopeall"
 100224 "Little Harbour (East), Placentia Bay"
 100225 "New Harbour, Trinity Bay"
 100226 "Old Shop"
 100227 "South Dildo"
 100228 "Thornlea"
 100229 "Freshwater, Conception Bay"
 100230 "New Chelsea-New Melbourne-Brownsdale-Sibley's Cove-Lead Cove"
 100231 "Burgoynes Cove"
 100232 "Deep Bight"
 100233 "George's Brook"
 100234 "Harcourt-Monroe-Waterville"
 100235 "Hickman's Harbour-Robinson Bight"
 100236 "Hillview-Adeytown"
 100237 "Hodges Cove"
 100238 "Lower Lance Cove"
 100239 "North West Brook-Ivany's Cove"
 100240 "Petley"
 100241 "Queen's Cove"
 100242 "Random Island West"
 100243 "Canning's Cove"
 100244 "Summerville-Princeton-Southern Bay"
 100245 "Birchy Cove"
 100246 "Newman's Cove"
 100247 "Open Hall-Red Cliffe"
 100248 "Spillars Cove"
 100249 "Upper Amherst Cove"
 100250 "Burnside-St. Chads"
 100251 "Markland"
 100252 "Brigus Junction"
 100253 "Makinsons"
 100255 "Roaches Line"
 100256 "Lance Cove, Bell Island"
 100259 "Grates Cove"
 100260 "Lodge Bay"
 100261 "Pensons Arm"
 100262 "William's Harbour"
 100263 "Black Tickle-Domino"
 100264 "Brigus South"
 100265 "Calvert"
 100266 "Mobile"
 100267 "Tors Cove"
 100268 "Forest Field-New Bridge"
 100269 "North Harbour, St. Mary's Bay"
 100270 "O'Donnells"
 100271 "Castor River South"
 100272 "Deep Bay"
 100273 "Dunfield"
 100274 "Eddies Cove West"
 100276 "Island Harbour"
 100277 "Norman's Bay"
 100278 "Piccadilly Head"
 100279 "Rock Harbour"
 100280 "Stag Harbour"
 100281 "Georgetown"
 100285 "Sheshatshiu"
 100322 "Campbells Creek part B"
 100324 "Goobies part B"
 100329 "Michaels Harbour"
 100341 "Dildo part B"
 100344 "Marysvale part A"
 100345 "Marysvale part B"
 100348 "Cavendish"
 100354 "L'Anse aux Meadows to Quirpon"
 120002 "Aylesford"
 120003 "Baddeck"
 120006 "Brooklyn"
 120007 "Canning"
 120008 "Carleton Corner"
 120009 "Centreville"
 120013 "Elmsdale"
 120014 "Enfield"
 120015 "Fall River"
 120016 "Falmouth"
 120019 "Freeport"
 120021 "Granville Ferry"
 120022 "Greenwood"
 120023 "Guysborough"
 120024 "Hants Border"
 120025 "Havre Boucher"
 120026 "Hebbville"
 120028 "Hillside"
 120033 "Lawrencetown"
 120034 "Lequille"
 120035 "Milton"
 120036 "Milton Highlands"
 120041 "Port Williams"
 120042 "Priestville"
 120043 "Pugwash"
 120045 "River Hebert"
 120048 "Sandy Point"
 120052 "Tatamagouche"
 120055 "Waverley"
 120056 "Wedgeport"
 120058 "Westport"
 120059 "Waterville"
 120060 "Cambridge"
 120061 "Shubenacadie part A"
 120062 "Shubenacadie part B"
 120063 "Coldbrook part A"
 120064 "Coldbrook part B"
 120068 "Black Point"
 120070 "Boutlier's Point"
 120071 "Brookfield"
 120073 "Cow Bay"
 120074 "Cornwallis Park"
 120077 "Donkin"
 120079 "Hubbards"
 120085 "Masstown"
 120087 "New Germany"
 120089 "Port Hastings"
 120092 "Terrence Bay"
 120095 "St. Margaret's Bay"
 130001 "Aldouane"
 130003 "Anse-Bleue"
 130005 "Baie du Petit Pokemouche / Baie du Petit-Pokemouche"
 130006 "Baie Ste. Anne / Baie-Sainte-Anne"
 130007 "Baie-Verte"
 130008 "Balmoral - St. Maure"
 130010 "Bayfield"
 130011 "Bayside"
 130012 "Beaver Harbour"
 130013 "Benoit"
 130014 "Benton part A / partie A"
 130017 "Blair Athol"
 130018 "Brantville"
 130020 "Cap-de-Richiboucto"
 130021 "Cape Tormentine"
 130024 "Chiasson-Savoy"
 130025 "Coldstream"
 130026 "Collette"
 130028 "Dalhousie Junction"
 130029 "Debec"
 130031 "Dugas"
 130032 "Dundee"
 130033 "Elgin"
 130034 "Escuminac"
 130035 "Fairfield"
 130036 "Flatlands part A / partie A"
 130037 "Fundy Bay"
 130038 "Glassville"
 130039 "Glencoe"
 130041 "Hanwell"
 130042 "Haut-Lamque"
 130043 "Upper Portage River / Haut-Rivire-du-Portage"
 130044 "Haut-Sheila"
 130045 "Inkerman Centre"
 130047 "Keswick Ridge"
 130049 "Lakeville"
 130050 "Laplante"
 130051 "Mann Mountain"
 130052 "McLeods"
 130054 "Miscou Island / le de Miscou"
 130055 "Murray Corner"
 130059 "Oak Point - Bartibog Bridge"
 130060 "Petit-Rocher-Nord (Deveraux)"
 130061 "Petit-Rocher-Sud"
 130062 "Petite-Lamque"
 130063 "Pigeon Hill"
 130064 "Pointe de Bute"
 130065 "Point La Nim / Pointe La Nim"
 130067 "Pointe-du-Chne"
 130068 "Pointe-Sapin"
 130069 "Pointe Sauvage (Indian Point)"
 130070 "Pointe LaFrance"
 130075 "Riley Brook"
 130076 "Robertville"
 130077 "St. Arthur / St-Arthur"
 130079 "Somerville"
 130081 "St.-Jean Baptiste-de-Restigouche / Saint-Jean-Baptiste-de-Restigouche"
 130082 "St. Margarets"
 130084 "St. Martin-de-Restigouche / St-Martin-de-Restigouche"
 130085 "Saint-Pons"
 130087 "St. Simon"
 130089 "Saint-Sauveur"
 130091 "Ste. Ccile / Sainte Ccile"
 130092 "Sunny Corner"
 130093 "Tabustinac"
 130094 "Tremblay"
 130095 "Upper Gagetown"
 130096 "Upper Kent / Haut-Kent"
 130097 "Upper Miramichi"
 130099 "Val-Comeau part A / partie A"
 130101 "Westfield"
 130102 "White Head Island"
 130103 "Wirral-Enniskillen"
 130109 "Saint Irne and Alderwood / Saint Irne et Alderwood"
 130110 "Pokemouche"
 130111 "Landry Office"
 130112 "Blanchard Settlement"
 130113 "Maltempec"
 130114 "Inkerman"
 130115 "Upper and Lower Northampton"
 130116 "Bonny-River - Second Falls"
 130117 "Dennis-Weston"
 130118 "Haut-Shippagan"
 130119 "Rivire  la Truite"
 130120 "Gauvreau-Petit Tracadie"
 130128 "North Tetagouche"
 130129 "Big River"
 130130 "Poirier"
 130131 "Pokesudie"
 130132 "Pointe-Canot"
 130133 "Coteau Road"
 130134 "Cap-Bateau"
 130135 "Pointe-Brle"
 130137 "Saumarez"
 130138 "Canton des Basques"
 130141 "Nicholas-Denys"
 130142 "Alcida"
 130143 "Madran"
 130145 "Dunlop"
 130146 "Saint-Laurent"
 130147 "Menneval"
 130151 "Seigas"
 130152 "St. Andr"
 130153 "Havelock part A / partie A"
 130157 "Fair Isle"
 130158 "Barryville-New Jersey"
 130159 "Leech"
 130161 "Pointe-Alexandre"
 130162 "Grand Barachois"
 130163 "Haute Aboujagane / Haute-Aboujagne"
 130164 "Boudreau West / Boudreau-Ouest"
 130166 "Scoudouc Road"
 130167 "Shediac Cape"
 130168 "Shediac Bridge - Shediac River"
 130169 "Grande-Digue"
 130174 "Saint-Ignace"
 130175 "Canisto Road / chemin Canisto"
 130176 "Nauwigewauk"
 130177 "Hampstead"
 130179 "Greater Lakeburn"
 130181 "Sainte-Rose part A / partie A"
 130182 "Evangline"
 130183 "Saint-Andr & LeBlanc Office / Saint-Andr & Leblanc Office"
 130184 "Carlisle Road"
 130185 "Estey's Bridge"
 130187 "Lincoln"
 130188 "Nevers Road"
 130189 "Noonan"
 130190 "Oswald Gray"
 130191 "Rusagonis-Waasis"
 130193 "Pointe--Bouleau"
 130194 "Black River-Hardwicke part A / partie A"
 130195 "Black River-Hardwicke part B / partie B"
 130196 "Portage River-Tracadie Beach part A / Rivire du Portage-Tracadie Beach partie A"
 130197 "Portage River-Tracadie Beach part B / Rivire du Portage-Tracadie Beach partie B"
 130198 "Renous-Quarryville part A / partie A"
 130199 "Renous-Quarryville part B / partie B"
 130200 "Val Comeau part B / partie B"
 130201 "Havelock part B / partie B"
 130202 "Lower Newcastle-Russellville part A / partie A"
 130203 "Lower Newcastle-Russellville part B / partie B"
 130204 "Scoudouc part A / partie A"
 130205 "Scoudouc part B / partie B"
 130206 "Flatlands part B / partie B"
 130208 "Val D'Amours part A / partie A"
 130209 "Val D'Amours part B / partie B"
 130210 "Val D'Amours part C / partie C"
 130211 "New Bandon-Salmon Beach part A / partie A"
 130212 "New Bandon-Salmon Beach part B / partie B"
 130213 "Benton part B / partie B"
 130214 "Grand Saint-Antoine part A / partie A"
 130215 "Grand Saint-Antoine part B / partie B"
 130216 "Grand Saint-Antoine part C / partie C"
 130217 "Sainte-Anne-de-Kent part A / partie A"
 130218 "Sainte-Anne-de-Kent part B / partie B"
 130219 "Western Charlotte part A / partie A"
 130220 "Western Charlotte part B / partie B"
 130223 "Notre-Dame-des-rables part A / partie A"
 130224 "Notre-Dame-des-rables part B / partie B"
 130225 "White's Brook part A / partie A"
 130226 "White's Brook part B / partie B"
 130227 "Cocagne part A / partie A"
 130228 "Cocagne part B / partie B"
 130229 "Pont Landry part A / partie A"
 130230 "Pont Landry part B / partie B"
 130231 "Pont Landry part C / partie C"
 130232 "Sainte-Rose part B / partie B"
 240003 "Sainte-Flicit"
 240006 "Saint-Gabriel"
 240007 "Sainte-Angle-de-Mrici"
 240008 "Sainte-Monique"
 240010 "Saint-Ours"
 240012 "L'Islet-sur-Mer"
 240013 "Saint-Louis-de-l'Isle-aux-Coudres"
 240014 "Saint-Bernard-de-l'le-aux-Coudres"
 240015 "Armagh"
 240016 "Saint-Charles"
 240017 "Saint-Vallier"
 240019 "Sault-au-Mouton"
 240028 "Beebe Plain"
 240031 "Saint-Liboire"
 240032 "L'Ange-Gardien"
 240035 "Saint-Sylvestre"
 240036 "Manseau"
 240037 "Saint-Alexandre"
 240038 "Chapeau"
 240039 "Saint-Polycarpe"
 240043 "Val-Brillant"
 240044 "Saint-Bernard"
 240045 "Saint-Elzar"
 240046 "Scott"
 240047 "Saint-Isidore"
 240049 "Saint-Patrice-de-Beaurivage"
 240050 "Deschaillons-sur-Saint-Laurent"
 240053 "Laurierville"
 240054 "Saint-Alban"
 240059 "Saint-Placide"
 240060 "Saint-Ludger"
 240062 "Inverness"
 240063 "La Prade"
 240064 "Les Becquets"
 240066 "Saint-Hermngilde"
 240067 "Fortierville"
 240068 "Sainte-Clotilde-de-Horton"
 240069 "La Patrie"
 240070 "Bishopton"
 240072 "Saint-Paulin"
 240073 "Saint-Guillaume"
 240074 "Aston-Jonction"
 240075 "Saint-Wenceslas"
 240076 "Frelighsburg"
 240077 "Clarenceville"
 240078 "Mont-Saint-Grgoire"
 240079 "Saint-Charles-sur-Richelieu"
 240081 "Les Cdres"
 240082 "Rivire-Beaudette"
 240093 "Saint-Victor"
 240094 "Saint-Zacharie"
 240100 "Neuville"
 240105 "Rock Island"
 240106 "Stanstead Plain"
 240107 "Upton"
 240108 "Saint-Lonard-d'Aston"
 240123 "Lac-Carr"
 240126 "Amqui"
 240170 "Kamouraska"
 240171 "Andrville"
 240178 "Lorrainville"
 240179 "Wottonville"
 240180 "Saint-Ulric"
 240181 "L'Isle-Verte"
 240182 "L'Islet"
 240183 "Beaulac"
 240184 "Sainte-Agathe"
 240185 "Saint-Flavien"
 240186 "Leclercville"
 240190 "Henryville"
 240191 "Saint-Chrysostome"
 240192 "Carillon"
 240193 "Ripon"
 240194 "Grandes-Bergeronnes"
 240195 "Saint-Simon"
 240196 "Sutton"
 240197 "Yamaska-Est"
 240198 "Yamaska"
 240199 "Lac-des-corces"
 240200 "Gracefield"
 240201 "Taschereau"
 240203 "Rivire-Saint-Paul"
 240204 "Blanc-Sablon"
 350001 "Campbell part A"
 350002 "Lee Valley"
 350003 "McGregor Bay part A"
 350004 "Robinson"
 350005 "Searchmont"
 350006 "Shakespeare"
 350007 "Willisville & Whitefish Falls"
 350008 "Oba"
 350009 "Rossport"
 350010 "Caramat"
 350011 "Nestor Falls part A"
 350012 "Redditt"
 350013 "Minaki"
 350014 "Wabigoon"
 350016 "Hudson"
 350017 "Madsen"
 350018 "Cartier"
 350020 "Restoule"
 350021 "Ferguson"
 350022 "Britt part A"
 350023 "Madawaska"
 350024 "Pearson"
 350025 "Kaministiquia"
 350026 "Lappe"
 350027 "Hurkett"
 350028 "Armstrong"
 350029 "Thorne"
 350030 "Alban part A"
 350031 "Savard"
 350032 "King-Lebel"
 350033 "Sultan"
 350034 "Gogama"
 350035 "Foleyet"
 350036 "Hawk Junction"
 350037 "Missanabie"
 350038 "Jogues"
 350039 "Lancaster"
 350040 "Finch"
 350041 "Maxville"
 350042 "St. Isidore"
 350043 "Plantagenet"
 350044 "Newboro"
 350045 "Lanark"
 350046 "Newburgh"
 350047 "Deloro"
 350048 "Bloomfield"
 350049 "Clifford"
 350050 "Vienna"
 350051 "Springfield"
 350052 "Erie Beach"
 350053 "Erieau"
 350054 "Highgate"
 350055 "Bothwell"
 350056 "Thamesville"
 350057 "Tiverton"
 350058 "Tara"
 350059 "Hepworth"
 350060 "Lion's Head"
 350061 "Neustadt"
 350062 "Flesherton"
 350063 "Chatsworth"
 350064 "Shallow Lake"
 350065 "Braeside"
 350066 "Chalk River"
 350067 "Cache Bay"
 350068 "Rosseau"
 350069 "Magnetawan"
 350070 "Webbwood"
 350071 "Iron Bridge"
 350072 "Athens"
 350073 "Woodville"
 350074 "Arkona"
 350075 "Thedford"
 350076 "Wardsville"
 350077 "Zurich"
 350078 "Bayfield"
 350079 "Blyth"
 350080 "Killaloe"
 350081 "Beachburg"
 350082 "Trout Creek"
 350083 "Nestor Falls part B"
 350084 "Campbell part B"
 350085 "McGregor Bay part B"
 350086 "Croft part A"
 350087 "Croft part B"
 350088 "Nestor Falls part C"
 350089 "Britt part B"
 350090 "Alban part B"
 460001 "Aghaming"
 460003 "Baden"
 460004 "Barrows"
 460005 "Berens River"
 460007 "Bissett"
 460008 "Brochet"
 460009 "Camperville"
 460010 "Cormorant"
 460011 "Crane River"
 460012 "Cross Lake"
 460013 "Dallas/Red Rose"
 460014 "Dauphin River"
 460015 "Dawson Bay"
 460016 "Duck Bay"
 460017 "Easterville"
 460018 "Fisher Bay"
 460019 "Gods Lake Narrows"
 460020 "Harwill"
 460021 "Herb Lake Landing"
 460022 "Homebrook"
 460023 "Island Lake"
 460024 "Little Grand Rapids"
 460026 "Loon Straits"
 460027 "Mallard"
 460028 "Manigotogan"
 460029 "Matheson Island"
 460030 "Meadow Portage"
 460031 "Moose Lake"
 460032 "National Mills"
 460033 "Nelson House"
 460034 "Norway House"
 460035 "Pelican Rapids"
 460036 "Pikwitonei"
 460037 "Pine Dock"
 460039 "Powell"
 460040 "Princess Harbour"
 460041 "Red Deer Lake"
 460042 "Red Sucker Lake"
 460043 "Rock Ridge"
 460044 "Salt Point"
 460045 "Seymourville"
 460046 "Sherridon"
 460048 "Spence Lake"
 460050 "Thicket Portage"
 460051 "Wabowden"
 460053 "Waterhen"
 460055 "Grunthal"
 460058 "Ashern"
 460059 "Fisher Branch"
 460066 "La Salle"
 460067 "Mitchell"
 460071 "Lorette"
 460072 "Landmark"
 460075 "Lundar"
 460076 "Lockport part A"
 460077 "Lockport part B"
 460080 "Blumenort"
 460081 "Falcon Lake"
 470001 "Alta Vista"
 470002 "Amsterdam"
 470003 "Ardill"
 470004 "Balone Beach"
 470005 "Bankend"
 470006 "Barrier Ford"
 470008 "Bayard"
 470009 "Beaubier"
 470010 "Beaver Creek"
 470011 "Bellegarde"
 470012 "Big Beaver"
 470013 "Blumenthal"
 470014 "Brancepeth"
 470015 "Cactus Lake"
 470016 "Candiac"
 470017 "Cannington Lake"
 470018 "Caron"
 470019 "Chelan"
 470020 "Chortitz"
 470021 "Claybank"
 470022 "Clemenceau"
 470023 "Congress"
 470024 "Corning"
 470025 "Courval"
 470026 "Crane Valley"
 470027 "Crooked River"
 470028 "Crutwell"
 470030 "Crystal Springs"
 470031 "Cudsaskwa Beach"
 470032 "Darlings Beach"
 470033 "Davin"
 470034 "Day's Beach"
 470035 "Delmas"
 470036 "Demaine"
 470039 "Edgeley"
 470040 "Elbow Lake"
 470041 "Eldersley"
 470042 "Erwood"
 470043 "Fairholme"
 470044 "Fairy Glen"
 470045 "Fiske"
 470046 "Frenchman Butte"
 470047 "Furdale"
 470048 "Garrick"
 470050 "Gray"
 470051 "Griffin"
 470052 "Gronlid"
 470053 "Hagen"
 470054 "Hazel Dell"
 470055 "Hendon"
 470057 "Hoey"
 470058 "Holbein"
 470059 "Indian Point-Golden Sands"
 470060 "Pelican Cove"
 470061 "Jasmin"
 470062 "Kandahar"
 470063 "Kayville"
 470064 "Ketchen"
 470065 "Kronau"
 470066 "Kuroki"
 470067 "Kylemore"
 470068 "Laporte"
 470071 "Lady Lake"
 470072 "Langbank"
 470073 "Lanz Point"
 470076 "Lisieux"
 470077 "Livelong"
 470078 "Lone Rock"
 470079 "MacDowall"
 470080 "Main Centre"
 470081 "Martinson's Beach"
 470082 "Mayfair"
 470083 "Maymont Beach"
 470084 "McCord"
 470085 "Meskanaw"
 470086 "Mikado"
 470087 "Moose Bay"
 470088 "Mozart"
 470089 "Mullingar"
 470090 "Neuanlage"
 470091 "Neuhorst"
 470092 "North Shore Fishing Lake"
 470093 "North Weyburn"
 470094 "Northside"
 470095 "Nut Mountain"
 470096 "Okla"
 470097 "Orkney"
 470098 "Ormiston"
 470099 "Otthon"
 470100 "Ottman-Murray Beach"
 470101 "Oungre"
 470102 "Parkview"
 470103 "Parry"
 470104 "Pasqua Lake"
 470105 "Pathlow"
 470106 "Peebles"
 470107 "Percival"
 470109 "Powm Beach"
 470110 "Prairie River"
 470111 "Prince"
 470115 "Riceton"
 470116 "Runnymede"
 470117 "Sarnia Beach"
 470118 "Scout Lake"
 470119 "Shipman"
 470120 "Simmie"
 470121 "Sleepy Hollow"
 470122 "Snowden"
 470123 "Sorenson's Beach"
 470124 "Spring Bay"
 470125 "St. Isidore-de-Bellevue"
 470128 "Sunset Beach"
 470130 "Swan Plain"
 470131 "Sylvania"
 470132 "Tadmore"
 470133 "Taylor Beach"
 470134 "Trevessa Beach"
 470135 "Trossachs"
 470136 "Tuffnell"
 470137 "Turtle Lake South Bay"
 470138 "Tway"
 470140 "Uhl's Bay"
 470141 "Usherville"
 470142 "Vantage"
 470143 "Westview"
 470144 "White Bear"
 470145 "Wymark"
 470146 "Phillips Grove"
 470147 "Good Spirit Acres"
 470148 "Bayview Heights"
 470149 "Pelican Point"
 470150 "West Chatfield Beach"
 470151 "Kopp's Kove"
 470152 "Nesslin Lake"
 470153 "Little Fishing Lake"
 470155 "Colesdale Park"
 470158 "Lakeview"
 470159 "Sand Point Beach"
 470160 "Evergreen Acres"
 470161 "Pelican Shores"
 470162 "Little Swan River"
 470163 "Horseshoe Bay"
 470165 "Evergreen Brightsand"
 470166 "Crystal Bay-Sunset"
 470167 "Parkland Beach"
 470168 "Hitchcock Bay"
 470170 "Burgis Beach"
 470171 "Cedar Villa Estates"
 470172 "Mohr's Beach"
 470173 "St. Joseph's"
 470174 "Arlington Beach"
 470175 "Spruce Bay"
 470176 "North Colesdale Park"
 470178 "Summerfield Beach"
 470179 "Wishart"
 470180 "Fife Lake"
 470182 "Crystal Lake part A"
 470183 "Crystal Lake part B"
 470195 "Guernsey"
 480001 "Acadia Valley"
 480002 "Alder Flats"
 480003 "Antler Lake"
 480004 "Anzac"
 480005 "Ardenode"
 480006 "Ardmore"
 480007 "Armena"
 480008 "Artists View Park West"
 480009 "Ashmont"
 480010 "Atmore"
 480011 "Balmoral NW"
 480012 "Balmoral SE"
 480013 "Beaver Lake"
 480014 "Beaver Mines"
 480015 "Benalto"
 480016 "Benchlands"
 480017 "Bezanson"
 480019 "Birch Hill Park"
 480020 "Bircham"
 480021 "Blackfoot"
 480022 "Blue Ridge"
 480023 "Bluesky"
 480024 "Bluffton"
 480025 "Bone Town"
 480026 "Bragg Creek"
 480027 "Braim"
 480028 "Brownvale"
 480029 "Brule"
 480030 "Buck Lake"
 480031 "Busby"
 480032 "Byemoor"
 480033 "Cadomin"
 480034 "Cadotte Lake"
 480035 "Calahoo"
 480037 "Canyon Creek"
 480038 "Canyon Heights"
 480039 "Carbondale"
 480041 "Carseland"
 480042 "Central Park"
 480043 "Centre Calling Lake"
 480044 "Chancellor"
 480045 "Cheadle"
 480046 "Chin"
 480047 "Chisholm"
 480048 "Clandonald"
 480049 "Clearwater Estates"
 480050 "Cochrane Lake Subd."
 480051 "Colinton"
 480054 "Collingwood Cove"
 480055 "Conklin"
 480056 "South Cooking Lake"
 480057 "Crystal Meadows"
 480058 "Dapp"
 480059 "Dawn Valley"
 480060 "Pigeon Mountain"
 480061 "Debolt"
 480062 "Desmarais"
 480063 "Devonshire Meadows"
 480064 "Diamond City"
 480065 "Dickson"
 480066 "Dixonville"
 480067 "Donatville"
 480068 "Duhamel"
 480069 "Dunmore"
 480070 "East Coulee"
 480071 "Ellscott"
 480072 "Endiang"
 480073 "Enilda"
 480074 "Erin Estates"
 480075 "Erskine"
 480076 "Exshaw"
 480077 "Faust"
 480078 "Fawcett"
 480079 "Ferrier Acres Trailer Court"
 480080 "Flatbush"
 480081 "Fleming Park"
 480082 "Flyingshot Lake"
 480083 "Fort Kent"
 480084 "Fort Vermilion"
 480085 "Gainford"
 480086 "Garden Grove Estates"
 480087 "Gift Lake part A"
 480088 "Glory Hills"
 480089 "Grandmuir Estates"
 480090 "Grassland"
 480091 "Green Acre Estates"
 480093 "Grouard Mission"
 480094 "Gwynne"
 480095 "Half Moon Estates"
 480096 "Harvie Heights"
 480097 "Haynes"
 480098 "Herder"
 480099 "Heritage Woods"
 480100 "Hesketh"
 480101 "Hewitt Estates"
 480102 "High Point Estates"
 480103 "Hilda"
 480104 "Hu Haven"
 480105 "Hubbles Lake"
 480106 "Huxley"
 480107 "Eldoes Trailer Park"
 480108 "Iron Springs"
 480109 "Islay"
 480110 "Jarvie"
 480111 "Joffre"
 480112 "Johnson's Addition"
 480113 "Josephburg"
 480114 "Joussard"
 480115 "Kelsey"
 480116 "Kikino part A"
 480117 "Kingman"
 480118 "Kounty Meadow Estates"
 480119 "La Crete"
 480120 "La Glace"
 480121 "Lac des Arcs"
 480122 "Langdon"
 480123 "Les Trailer Park"
 480124 "Leslieville"
 480125 "Linn Valley"
 480126 "Lodgepole"
 480127 "Long Lake"
 480129 "Lousana"
 480130 "Lower Manor Estates"
 480131 "Lowland Heights"
 480132 "Lundbreck"
 480133 "Lyalta"
 480134 "Mackay"
 480135 "Mallaig"
 480136 "Markerville"
 480137 "Marlboro"
 480138 "Martins Trailer Court"
 480139 "McDermott"
 480140 "McNabb's"
 480141 "Meanook"
 480142 "Meeting Creek"
 480143 "Meso West"
 480144 "Monarch"
 480145 "Moon River Estates"
 480146 "Morningside"
 480147 "Mountain View"
 480148 "Mulhurst part A"
 480150 "Namaka"
 480151 "Namao"
 480152 "Nestow"
 480153 "Nevis"
 480154 "Newbrook"
 480155 "Nightingale"
 480156 "Niton Junction"
 480157 "Calling Lake"
 480158 "Obed"
 480159 "Ohaton"
 480160 "Orton"
 480161 "Osborne Acres"
 480162 "Paddle Prairie"
 480163 "Panorama Heights"
 480166 "Patricia"
 480167 "Peers"
 480168 "Sandy Lake"
 480169 "Perryvale"
 480170 "Peterburn Estates"
 480171 "Pibroch"
 480172 "Picardville"
 480173 "Pincher Station"
 480174 "Pine Shadows"
 480175 "Poplar Ridge"
 480176 "Ralston"
 480177 "Ranfurly"
 480178 "Red Earth Creek"
 480179 "Red Willow"
 480180 "Redland"
 480181 "Reno"
 480182 "Riverview Pines Subdivision"
 480183 "Robb"
 480184 "Rochester"
 480185 "Rolling Hills"
 480186 "Rolling Heights"
 480187 "Rolling Meadows"
 480188 "Rosebud"
 480189 "Rosedale"
 480190 "Rossian"
 480191 "Round Hill"
 480193 "Scandia"
 480194 "Schuler"
 480195 "Seebe"
 480196 "Seven Persons"
 480197 "Shaftsbury Settlement"
 480198 "Shaughnessy"
 480199 "Shepard"
 480200 "Smith"
 480201 "Spruce Lane Acres"
 480202 "Spruce View"
 480203 "St Isidore"
 480204 "Suffield"
 480205 "Sundance Power Plant"
 480206 "Sunnyslope"
 480207 "Sunset Acres"
 480208 "Sunset View Acres"
 480209 "Swalwell"
 480210 "Tawatinaw"
 480211 "Tees"
 480212 "Tomahawk"
 480213 "Triple-L-Trailer Court"
 480214 "Turin"
 480215 "Twin Butte"
 480216 "Upper and Lower Viscount Estates"
 480217 "Upper Manor Estates"
 480218 "Valhalla Centre"
 480220 "Villeneuve"
 480221 "Vimy"
 480222 "Wabasca"
 480223 "Walsh"
 480225 "Westbrooke Crescents"
 480226 "Westlake Estates"
 480227 "Eastview Acres"
 480228 "Whitelaw"
 480229 "Widewater"
 480230 "Wimborne"
 480231 "Winfield"
 480232 "Woking"
 480233 "Woodbend Crescent"
 480234 "Woodland Hills"
 480235 "Woodland Park"
 480236 "Zama City"
 480237 "Hobbema"
 480238 "Prairie Lodge Trailer Court"
 480239 "Trout Lake"
 480240 "Peerless Lake"
 480241 "Chipewyan Lake"
 480243 "Fort Chipewyan"
 480246 "T & E Trailer Park"
 480247 "Swan City Trailer Court"
 480249 "Waterton Park"
 480251 "Elkwater"
 480253 "Buffalo Lake"
 480254 "Elizabeth"
 480255 "Fishing Lake"
 480258 "East Prairie"
 480259 "Peavine"
 480260 "Gregoire Lake Estates"
 480261 "Saprae Creek"
 480262 "Janvier South"
 480263 "Bristol Oakes"
 480265 "Grassy Lake"
 480266 "Gleichen"
 480267 "Cayley"
 480268 "Blackie"
 480269 "Evansburg"
 480270 "Mirror"
 480271 "Plamondon"
 480272 "Mulhurst part B"
 480274 "Gift Lake part B"
 480275 "Kikino part B"
 480276 "Torrington"
 480278 "Springbrook"
 480279 "Hillcrest Mines"
 480280 "Hayter"
 480281 "Gunn"
 480282 "Frank"
 480284 "Eaglesham"
 480286 "Cadogan"
 480287 "Cluny"
 480292 "Wildwood"
 590002 "Denman Island Trust Area"
 590003 "Gabriola Island Trust Area part A"
 590004 "Galiano Island Trust Area"
 590006 "Hornby Island Trust Area"
 590007 "Lasqueti Island Trust Area"
 590008 "Mayne Island Trust Area"
 590009 "North Pender Island Trust Area"
 590011 "Saturna Island Trust Area"
 590012 "Thetis Island Trust Area part A"
 590013 "South Pender Island Trust Area"
 590020 "Gillies Bay"
 590021 "Lund"
 590022 "Vananda"
 590023 "Myrtle Point"
 590024 "Barney's Bar"
 590025 "Pinetree"
 590026 "Black Point"
 590027 "Brew Bay"
 590028 "Lang Bay"
 590029 "Stillwater"
 590030 "Garden Bay"
 590031 "Halfmoon Bay"
 590032 "Hopkins Landing"
 590033 "Roberts Creek"
 590034 "South Pender Harbour"
 590035 "Beaverdell"
 590036 "Beaver Falls"
 590037 "Christina Lake"
 590038 "Genelle"
 590039 "Sion"
 590041 "Lindell Beach"
 590042 "Hatzic Island"
 590043 "Durieu"
 590044 "Lake Errock"
 590045 "Deroche"
 590046 "Cultus Lake"
 590048 "Baker Trails"
 590049 "Bell Acres"
 590050 "Slesse Park"
 590051 "West Popkum"
 590052 "East Popkum"
 590053 "Harrison Mills"
 590054 "Hemlock Valley"
 590055 "Laidlaw"
 590056 "Sunshine Valley"
 590057 "Dogwood Valley"
 590058 "Yale"
 590059 "North Bend"
 590060 "Boston Bar"
 590061 "Cowichan Bay"
 590062 "Cherry Point"
 590063 "Cobble Hill"
 590064 "Arbutus Ridge"
 590065 "Mill Bay"
 590066 "Shawnigan Lake"
 590068 "Saltair"
 590069 "North Oyster/Yellow Point"
 590070 "Diamond"
 590071 "Honeymoon Bay/Mesachie Lake"
 590072 "Youbou"
 590073 "Kelly Lake"
 590074 "Arras-Devereaux"
 590075 "Wabi Hill"
 590076 "Dokie-Wildmare"
 590077 "Moberly Lake"
 590078 "Rolla"
 590079 "Fort St. John Airport"
 590080 "Charlie Lake part A"
 590081 "Mile 62.5/63"
 590082 "Prespatou"
 590083 "Dodge Cove"
 590084 "Sandspit"
 590085 "Tlell"
 590087 "Cherry Creek part A"
 590088 "Sproat Lake"
 590089 "Bamfield"
 590090 "Canal Flats"
 590091 "Edgewater"
 590092 "Fairmont Hot Springs"
 590093 "Windermere"
 590094 "Jaffray"
 590095 "West Fernie"
 590096 "Hosmer"
 590097 "Wycliffe"
 590098 "Wasa Lake"
 590099 "Wilmer"
 590100 "Mud Bay"
 590101 "Buckley Bay"
 590102 "Union Bay"
 590103 "Royston"
 590104 "Fanny Bay"
 590105 "Read Island"
 590106 "Heriot Bay"
 590107 "Quathiaski Cove"
 590109 "Kaleden"
 590111 "Cawston"
 590112 "Naramata"
 590113 "Saratoga-Miracle Beach"
 590114 "Bear Lake"
 590115 "Hedley"
 590116 "Willow River"
 590117 "Hixon"
 590118 "Manson's Landing"
 590119 "Ainsworth"
 590120 "Balfour"
 590122 "Bonnington"
 590123 "Brilliant"
 590124 "Burton"
 590125 "Crawford Bay"
 590126 "Edgewood"
 590127 "Fauquier"
 590128 "Glade"
 590129 "Harrop/Procter"
 590130 "Kitchener"
 590131 "Ootischenia"
 590132 "Riondel"
 590133 "Robson/Raspberry"
 590134 "Shoreacres"
 590135 "Six Mile"
 590136 "Taghum"
 590137 "Winlaw"
 590138 "Wynndel part A"
 590139 "Yahk"
 590140 "Ymir"
 590141 "Olalla"
 590142 "103 Mile"
 590143 "150 Mile House"
 590144 "Alexis Creek"
 590145 "Anahim Lake"
 590146 "Anderson Subdivision"
 590147 "Barlow Creek part A"
 590148 "Big Lake"
 590149 "Commodore Heights"
 590150 "Chilcotin Road Area"
 590151 "Dog Creek Road Area"
 590152 "Esler Subdivision"
 590153 "Forest Grove"
 590154 "Fox Mountain"
 590155 "Gateway/Buffalo Creek"
 590156 "Horsefly"
 590157 "Imperial Ranchettes"
 590158 "Kersley"
 590159 "Lac la Hache"
 590160 "Lone Butte"
 590161 "McLeese Lake"
 590162 "Mile 108 Recreational Ranch"
 590163 "North Lakeside"
 590164 "Pine Valley"
 590165 "South Lakeside"
 590166 "Wildwood"
 590167 "Decker Lake"
 590168 "Evelyn"
 590169 "Fort Fraser"
 590170 "Southbank"
 590171 "Tintagle"
 590172 "Topley"
 590173 "Ellison"
 590174 "Lakeview"
 590175 "Westbank"
 590176 "Coal Harbour"
 590177 "Hyde Creek"
 590178 "Sointula"
 590179 "Cassidy"
 590180 "Cedar"
 590181 "Coombs"
 590182 "Dashwood"
 590183 "Deep Bay/Bowser"
 590184 "Dunsmuir"
 590185 "East Wellington"
 590186 "Englishman River North"
 590187 "Englishman River South"
 590188 "Errington"
 590189 "Extension"
 590190 "French Creek"
 590191 "Hilliers"
 590192 "Lantzville"
 590193 "Nanoose Bay"
 590194 "Qualicum Bay"
 590195 "South Wellington part A"
 590196 "Anglemont"
 590197 "Blind Bay"
 590198 "Canoe Point"
 590199 "Cedar Hill/Glenemma"
 590200 "Celista"
 590201 "Deep Creek"
 590202 "Eagle Bay"
 590203 "Falkland"
 590204 "Lee Creek"
 590205 "Magna Bay"
 590206 "Malakwa"
 590207 "Notch Hill"
 590208 "Ranchero"
 590209 "Scotch Creek"
 590210 "Seymour Arm"
 590211 "Silver Creek"
 590212 "Solsqua"
 590213 "Sorrento"
 590214 "Sunnybrae"
 590215 "Swansea Point"
 590216 "Tappen"
 590217 "White Lake"
 590218 "BX/Silver Star Foothills"
 590219 "Cherryville"
 590220 "Grindrod"
 590221 "Kingfisher"
 590222 "Mara"
 590223 "Shuswap Falls"
 590224 "Silver Star"
 590225 "Bella Coola"
 590228 "Dease Lake"
 590229 "Grand Haven/Clairmont"
 590231 "South Hazelton"
 590232 "Gabriola Island Trust Area part B"
 590233 "Gabriola Island Trust Area part C"
 590234 "Saltspring Island Trust Area part A"
 590235 "Saltspring Island Trust Area part B"
 590236 "Saltspring Island Trust Area part C"
 590237 "Saltspring Island Trust Area part D"
 590238 "Saltspring Island Trust Area part E"
 590239 "Saltspring Island Trust Area part F"
 590240 "Saltspring Island Trust Area part G"
 590241 "Saltspring Island Trust Area part H"
 590242 "Charlie Lake part B"
 590243 "South Wellington part B"
 590244 "Merville part A"
 590245 "Merville part B"
 590246 "Merville part C"
 590247 "Barlow Creek part B"
 590248 "Thetis Island Trust Area part B"
 590249 "Gambier Island Trust Area part A"
 590250 "Gambier Island Trust Area part B"
 590251 "Gambier Island Trust Area part C"
 590252 "Gambier Island Trust Area part D"
 590253 "Gambier Island Trust Area part E"
 590258 "Wynndel part B"
 590263 "Hagensborg part A"
 590264 "Hagensborg part B"
 590266 "Barriere"
 590271 "Two Mile"
 590273 "Lower Nicola"
 600001 "Carmacks Landing Settlement"
 /
 urbnarea
 0 "Not urban area: postal code linked to dissemination area only (REPPOINT=3)"
 100786 "St. Anthony"
 101080 "Musgrave Harbour"
 100082 "Bonavista"
 100469 "Lewisporte"
 101056 "Gambo"
 100778 "Springdale"
 100438 "Labrador City"
 100072 "Bishop's Falls"
 100332 "Grand Falls-Windsor"
 100182 "Clarenville-Shoal Harbour"
 100994 "Wabana"
 101178 "Goulds"
 100136 "Carbonear"
 100792 "St. John's"
 100219 "Deer Lake"
 101203 "Pasadena"
 101285 "Humber Arm South"
 100247 "Dunville"
 100204 "Corner Brook"
 100355 "Harbour Breton"
 100888 "Stephenville"
 100509 "Marystown"
 100329 "Grand Bank"
 100300 "Fortune"
 100107 "Burgeo"
 100311 "Gander"
 100084 "Botwood"
 101119 "Arnold's Cove"
 100889 "Stephenville Crossing"
 100354 "Happy Valley-Goose Bay"
 100046 "Bay Roberts"
 100155 "Channel-Port aux Basques"
 110772 "Souris"
 111155 "Alberton"
 110407 "Kensington"
 110159 "Charlottetown"
 111121 "Cornwall"
 110905 "Summerside"
 110544 "Montague"
 120581 "New Waterford"
 120318 "Glace Bay"
 120914 "Sydney Mines"
 120913 "Cape Breton - Sydney"
 120390 "Inverness"
 120661 "Port Hawkesbury"
 120019 "Antigonish"
 120642 "Pictou"
 120577 "New Glasgow"
 120621 "Oxford"
 120012 "Amherst"
 120779 "Springhill"
 120955 "Truro"
 120627 "Parrsboro"
 121304 "Lantz"
 120353 "Hantsport"
 121030 "Windsor"
 121267 "Lake Echo"
 121343 "Hayes Subdivision"
 120069 "Berwick"
 120348 "Halifax"
 120416 "Kingston - Greenwood"
 121353 "Brookside"
 120530 "Middleton"
 120171 "Chester"
 120490 "Lunenburg"
 120096 "Bridgewater"
 120229 "Digby"
 120477 "Liverpool"
 120754 "Shelburne"
 121043 "Yarmouth"
 120408 "Kentville"
 121037 "Wolfville"
 121354 "Hammonds Plains Road"
 121344 "Enfield"
 120095 "Bridgetown"
 130760 "Shippagan"
 130134 "Caraquet"
 130214 "Dalhousie"
 130946 "Tracadie-Sheila"
 130122 "Campbellton"
 130045 "Bathurst"
 130401 "Kedgwick"
 130797 "Saint-Quentin"
 131105 "Chatham - Douglastown"
 130702 "Richibucto"
 130723 "Rogersville"
 130105 "Bouctouche"
 130253 "Edmundston"
 131288 "Sainte-Anne-de-Madawaska"
 130753 "Shediac"
 131158 "St. Leonard"
 130331 "Grand-Sault"
 131352 "McEwen"
 130650 "Plaster Rock"
 130539 "Moncton"
 130732 "Sackville"
 130635 "Perth-Andover"
 130907 "Sussex"
 130612 "Oromocto"
 130305 "Fredericton"
 131038 "Woodstock"
 130350 "Hampton"
 130734 "Saint John"
 130518 "McAdam"
 130798 "St. Stephen"
 130784 "Saint Andrews"
 130735 "Salisbury"
 241061 "Fermont"
 240364 "Havre-Saint-Pierre"
 240748 "Sept-les"
 240668 "Port-Cartier"
 241066 "Rivire-au-Renard"
 241064 "Gasp"
 240876 "Sainte-Anne-des-Monts"
 240130 "Cap-Chat"
 240154 "Chandler"
 240129 "Cap-aux-Meules"
 241339 "Mistissini"
 241284 "Hauterive"
 240181 "Chute-aux-Outardes"
 240515 "Matane"
 241338 "Betsiamites"
 240580 "New Richmond"
 240081 "Bonaventure"
 241337 "Carleton"
 240016 "Amqui"
 240677 "Price"
 240149 "Causapscal"
 240540 "Mont-Joli"
 240175 "Chibougamau"
 240286 "Forestville"
 240488 "Luceville"
 240122 "Campbellton"
 240156 "Chapais"
 241238 "Le Bic"
 240822 "Saint-Fabien"
 240266 "Les Escoumins"
 240231 "Dolbeau"
 240952 "Trois-Pistoles"
 240832 "Saint-Honor"
 240839 "Saint-Jean-de-Dieu"
 240009 "Alma"
 241072 "Port-Alfred-Bagotville"
 240176 "Chicoutimi - Jonquire"
 240368 "Saint-Bruno"
 240715 "Roberval"
 240841 "Mtabetchouan"
 240111 "Cabano"
 240223 "Desbiens"
 240712 "Rivire-du-Loup"
 240565 "Notre-Dame-du-Lac"
 240220 "Dgelis"
 241277 "Saint-Alexandre"
 240186 "Clermont"
 240854 "Saint-Pascal"
 240852 "Saint-Pacme"
 240432 "La Pocatire"
 240037 "Baie-Saint-Paul"
 240434 "La Sarre"
 240015 "Amos"
 240746 "Senneterre"
 240041 "Barraute"
 240546 "Montmagny"
 240050 "Beaupr"
 240435 "La Tuque"
 240162 "Chteau-Richer"
 240858 "Saint-Raphal"
 240965 "Val-d'Or"
 240498 "Malartic"
 240728 "Rouyn-Noranda"
 240816 "Saint-Damien-de-Buckland"
 240859 "Saint-Raymond"
 240831 "Saint-Henri-de-Lvis"
 240805 "Saint-Anselme"
 240877 "Sainte-Claire"
 240685 "Qubec"
 240807 "Saint-Basile-Sud"
 241154 "Sainte-Justine"
 240442 "Lac-Etchemin"
 240302 "Saint-Apollinaire"
 240670 "Portneuf"
 240885 "Sainte-Thcle"
 240800 "Saint-Agapit"
 240878 "Sainte-Croix"
 240849 "Saint-Marc-des-Carrires"
 240882 "Sainte-Marie"
 240969 "Valle-Jonction"
 241286 "Laurier-Station"
 240866 "Saint-Tite"
 240857 "Saint-Prosper"
 240844 "Saint-Joseph-de-Beauce"
 240828 "Saint-Georges"
 240473 "Linire"
 240054 "Gentilly"
 241341 "Notre-Dame-du-Mont-Carmel"
 241235 "Saint-phrem-de-Tring"
 240750 "Shawinigan"
 240079 "Saint-Martin"
 240651 "Plessisville"
 240066 "Bernierville"
 240929 "Thetford Mines"
 240682 "Princeville"
 241123 "Daveluyville"
 240826 "Saint-Gdon"
 241358 "Saint Grgoire"
 240953 "Trois-Rivires"
 240197 "Coleraine"
 240587 "Nicolet"
 240485 "Louiseville"
 240230 "Disraeli"
 240987 "Victoriaville"
 241145 "Maskinong"
 240989 "Ville-Marie"
 240564 "Notre-Dame-du-Bon-Conseil"
 240644 "Pierreville"
 240819 "Saint-Donat-de-Montcalm"
 240824 "Saint-Flix-de-Valois"
 241287 "Kingsey Falls"
 240541 "Mont-Laurier"
 240443 "Lac-Mgantic"
 241008 "Weedon Centre"
 240005 "Alenon"
 240421 "L'Annonciation"
 240023 "Asbestos"
 241186 "Danville"
 240770 "Sorel"
 240240 "Drummondville"
 240830 "Saint-Germain-de-Grantham"
 240437 "Labelle"
 240396 "Joliette"
 240692 "Rawdon"
 240209 "Crabtree"
 240705 "Richmond"
 240835 "Saint-Jacques"
 241184 "Sainte-Julienne"
 240201 "Contrecoeur"
 240847 "Saint-Jovite"
 240500 "Maniwaki"
 241033 "Windsor"
 241336 "Val-David"
 240250 "East Angus"
 240875 "Sainte-Agathe-des-Monts"
 241252 "Lac-Lapierre"
 240002 "Acton Vale"
 241342 "Saint-Roch-de-l'Achigan"
 240202 "Cookshire"
 241335 "Saint-Liboire"
 240874 "Sainte-Adle"
 241326 "Saint-Denis"
 240729 "Roxton Falls"
 240458 "Laurentides"
 240920 "Tmiscaming"
 241334 "Lac-Alouette"
 241318 "Filion"
 241179 "Sainte-Anne-des-Plaines"
 240881 "Sainte-Madeleine"
 240842 "Saint-Jrme"
 241333 "Roxton Pond"
 240815 "Saint-Damase"
 240758 "Sherbrooke"
 240855 "Saint-Pie"
 240063 "Beloeil"
 241270 "Saint-Canut"
 241332 "Rougemont"
 241004 "Waterloo"
 240328 "Granby"
 240505 "Marieville"
 240189 "Coaticook"
 241359 "Bromont"
 241205 "Brownsburg"
 240444 "Lachute"
 240803 "Saint-Andr-Avellin"
 240365 "Hawkesbury"
 240276 "Farnham"
 240208 "Cowansville"
 241362 "Oka-Kanesatake"
 240623 "Papineauville"
 240707 "Rigaud"
 240836 "Saint-Jean-sur-Richelieu"
 240547 "Montral"
 240936 "Thurso"
 240861 "Saint-Rmi"
 240056 "Bedford"
 240299 "Fort-Coulonge"
 241177 "Chteauguay"
 241361 "Les Cdres"
 240883 "Sainte-Martine"
 241051 "Buckingham"
 240445 "Lacolle"
 240971 "Salaberry-de-Valleyfield"
 241127 "Les Coteaux"
 240611 "Ormstown"
 240382 "Huntingdon"
 240616 "Ottawa - Gatineau"
 240514 "Matagami"
 240591 "Normandin"
 240823 "Saint-Flicien"
 240840 "Saint-Jean-Port-Joli"
 240653 "Pont-Rouge"
 240233 "Donnacona"
 240047 "Beauceville"
 240801 "Saint-Alexis-des-Monts"
 241000 "Warwick"
 240067 "Berthierville"
 240460 "Lavaltrie"
 240968 "Valcourt"
 240495 "Magog"
 240570 "Napierville"
 241386 "Waskaganish"
 240036 "Baie-Comeau"
 240709 "Rimouski"
 240464 "Lebel-sur-Quvillon"
 240279 "Ferme-Neuve"
 240834 "Saint-Hyacinthe"
 240811 "Saint-Csaire"
 241340 "Chisasibi"
 240337 "Grande-Rivire"
 240740 "Sayabec"
 241292 "L'Ascension-de-Notre-Seigneur"
 240802 "Saint-Ambroise"
 240561 "Hbertville"
 240430 "La Malbaie"
 240492 "Macamic"
 240251 "East Broughton"
 240850 "Saint-Michel-des-Saints"
 241042 "Yamachiche"
 240825 "Saint-Gabriel"
 241148 "Saint-Cyrille-de-Wendover"
 240846 "Saint-Joseph-de-Lanoraie"
 240424 "L'piphanie"
 240863 "Saint-Sauveur-des-Monts"
 241363 "Saint-Augustin"
 240752 "Shawville"
 351275 "Attawapiskat 91A"
 351390 "Moosonee"
 350038 "Golden"
 350367 "Hearst"
 350400 "Kapuskasing"
 350315 "Geraldton"
 350241 "Dryden"
 350192 "Cochrane"
 350392 "Iroquois Falls"
 350499 "Manitouwadge"
 351099 "Timmins"
 350923 "Terrace Bay"
 350504 "Marathon"
 350028 "Atikokan"
 350290 "Fort Frances"
 350264 "Englehart"
 350935 "Thunder Bay"
 350157 "Chapleau"
 350347 "Haileybury"
 350133 "Capreol"
 350516 "Mattawa"
 350427 "L'Orignal"
 350365 "Hawkesbury"
 350468 "Onaping - Levack"
 351084 "Dowling"
 350975 "Vankleek Hill"
 350901 "Sturgeon Falls"
 350904 "Sudbury"
 350719 "Rockland"
 351086 "Petawawa"
 351102 "Lively"
 350631 "Pembroke"
 350006 "Alexandria"
 350672 "Powassan"
 350144 "Casselman"
 350257 "Elliot Lake"
 350739 "Sault Ste. Marie"
 350267 "Espanola"
 351306 "Russell"
 350021 "Arnprior"
 350699 "Renfrew"
 351323 "Metcalfe"
 350773 "South River"
 350399 "Kanata"
 350172 "Chesterville"
 350928 "Thessalon"
 350205 "Cornwall"
 350076 "Blind River"
 350704 "Richmond"
 351264 "Osgoode"
 350044 "Barry's Bay"
 351322 "Munster"
 350475 "Little Current"
 350140 "Carleton Place"
 350405 "Kemptville"
 350556 "Morrisburg"
 350391 "Iroquois"
 351305 "Wikwemikong"
 350137 "Cardinal"
 350766 "Smiths Falls"
 350634 "Perth"
 350383 "Huntsville"
 350628 "Parry Sound"
 350098 "Brockville"
 350339 "Gravenhurst"
 350310 "Gananoque"
 350494 "Madoc"
 350957 "Tweed"
 350508 "Marmora"
 351327 "Amigo Beach"
 350363 "Havelock"
 350531 "Midland"
 350415 "Kingston"
 350277 "Fenelon Falls"
 350569 "Napanee"
 350600 "Norwood"
 350450 "Lakefield"
 350610 "Orillia"
 350892 "Stirling"
 350121 "Campbellford"
 351241 "Hastings"
 351026 "Wiarton"
 350094 "Bridgenorth - Chemong Park Area"
 350303 "Frankford"
 350053 "Beaverton"
 350522 "Meaford"
 350472 "Lindsay"
 351307 "Omemee"
 350636 "Peterborough"
 350932 "Thornbury"
 350198 "Collingwood"
 351331 "Wasaga Beach"
 350641 "Picton"
 350871 "Stayner"
 350908 "Sutton"
 351308 "Millbrook"
 350097 "Brighton"
 351159 "Wellington"
 350193 "Colborne"
 351132 "Creemore"
 350043 "Barrie"
 350018 "Angus - Borden CFB-BFC"
 350665 "Port Perry"
 351272 "Mount Albert"
 350506 "Markdale"
 351248 "Cookstown"
 350190 "Cobourg"
 350963 "Uxbridge"
 350662 "Port Hope"
 350613 "Orono"
 350170 "Chesley"
 351128 "Paisley"
 351370 "Ballantrae"
 350244 "Dundalk"
 350058 "Beeton"
 350248 "Durham"
 350755 "Shelburne"
 350945 "Tottenham"
 351357 "Schomberg"
 350352 "Hanover"
 350614 "Oshawa"
 350998 "Walkerton"
 350412 "Kincardine"
 351071 "Nobleton"
 350080 "Bolton"
 351301 "Mildmay"
 351356 "Caledon East"
 350609 "Orangeville"
 350558 "Mount Forest"
 351319 "Caledon"
 351129 "Grand Valley"
 350359 "Harriston"
 350489 "Lucknow"
 350022 "Arthur"
 350265 "Erin"
 350622 "Palmerston"
 351034 "Wingham"
 351317 "Drayton"
 350314 "Georgetown"
 350278 "Fergus"
 350001 "Acton"
 350474 "Listowel"
 351295 "Brussels"
 350532 "Milton"
 350324 "Goderich"
 350258 "Elmira"
 351245 "St. Jacobs"
 350533 "Milverton"
 350944 "Toronto"
 350187 "Clinton"
 351255 "Carlisle"
 351083 "Mississauga Beach"
 350744 "Seaforth"
 351371 "Virgil"
 350538 "Mitchell"
 350419 "Kitchener"
 350578 "New Hamburg"
 351243 "Hensall"
 351269 "Vineland"
 350897 "Stratford"
 350919 "Tavistock"
 351315 "St. George"
 350349 "Hamilton"
 350272 "Exeter"
 350624 "Paris"
 350795 "St. Marys"
 350092 "Brantford"
 351297 "Grand Bend"
 351313 "Burford"
 351062 "Fort Erie"
 350487 "Lucan"
 351039 "Woodstock"
 350788 "St. Catharines - Niagara"
 350150 "Cayuga"
 350246 "Dunnville"
 350346 "Hagersville"
 350625 "Parkhill"
 350925 "Thamesford"
 350599 "Norwich"
 350386 "Ingersoll"
 351003 "Waterford"
 351151 "Jarvis"
 350285 "Forest"
 350762 "Simcoe"
 350221 "Delhi"
 351372 "Komoka"
 350658 "Port Dover"
 350939 "Tillsonburg"
 350480 "London"
 350899 "Strathroy"
 351239 "Belmont"
 350557 "Mount Brydges"
 351006 "Watford"
 351041 "Wyoming"
 350030 "Aylmer"
 350639 "Petrolia"
 350799 "St. Thomas"
 350321 "Glencoe"
 350737 "Sarnia"
 350666 "Port Stanley"
 351170 "Dutton"
 351011 "West Lorne"
 351207 "Rodney"
 350238 "Dresden"
 350999 "Wallaceburg"
 350706 "Ridgetown"
 350167 "Chatham"
 350075 "Blenheim"
 351312 "Stoney Point"
 350938 "Tilbury"
 351032 "Windsor"
 350268 "Essex"
 351017 "Wheatley"
 350014 "Amherstburg"
 350360 "Harrow"
 350463 "Leamington"
 351147 "Colchester"
 351391 "Fort Albany (Part) 67"
 350970 "Valley East"
 351321 "Constance Bay"
 350010 "Almonte"
 350088 "Bracebridge"
 350225 "Deseronto"
 350619 "Owen Sound"
 351330 "Everett"
 351020 "Stouffville"
 351316 "Hillsburgh"
 350343 "Guelph"
 350031 "Ayr"
 351063 "Crystal Beach"
 351389 "Red Lake"
 350763 "Sioux Lookout"
 350394 "Wawa"
 350260 "Embrun"
 350616 "Ottawa - Gatineau"
 350061 "Belleville"
 350659 "Port Elgin"
 350089 "Bradford"
 351075 "Beamsville"
 350114 "Caledonia"
 350481 "Longlac"
 350406 "Kenora"
 351100 "Porcupine"
 350418 "Kirkland Lake"
 350218 "Deep River"
 350007 "Alfred"
 350595 "North Bay"
 350256 "Eganville"
 351029 "Winchester"
 350675 "Prescott"
 350077 "Bobcaygeon"
 350259 "Elmvale"
 350126 "Cannington"
 351176 "Southampton"
 350008 "Alliston"
 350087 "Bowmanville - Newcastle"
 351298 "Teeswater"
 351209 "Rockwood"
 351299 "Wellesley"
 350767 "Smithville"
 460930 "Thompson"
 460282 "Flin Flon"
 460927 "The Pas"
 460716 "Roblin"
 460730 "Russell"
 460317 "Gimli"
 460534 "Minnedosa"
 460572 "Neepawa"
 460894 "Stonewall"
 460991 "Virden"
 460745 "Selkirk"
 460645 "Pinawa"
 460051 "Beausejour"
 460135 "Carberry"
 460091 "Brandon"
 460759 "Shilo CFB-BFC"
 461365 "Oakbank"
 460771 "Souris"
 461036 "Winnipeg"
 461373 "Lorette"
 461254 "St. Adolphe"
 460872 "Ste. Anne"
 461133 "Niverville"
 460525 "Melita"
 460142 "Carman"
 460887 "Steinbach"
 460078 "Boissevain"
 460555 "Morris"
 460410 "Killarney"
 461035 "Winkler"
 460215 "Dauphin"
 461225 "Lac du Bonnet"
 460669 "Portage la Prairie"
 460553 "Morden"
 460911 "Swan River"
 460710 "Rivers"
 460895 "Stony Mountain"
 460011 "Altona"
 471379 "Stanley 157"
 471188 "La Ronge"
 470521 "Meadow Lake"
 470282 "Flin Flon"
 470756 "Shellbrook"
 470678 "Prince Albert"
 470594 "North Battleford"
 470960 "Unity"
 471027 "Wilkie"
 470726 "Rosthern"
 470524 "Melfort"
 471230 "Langham"
 470380 "Hudson Bay"
 471137 "Warman"
 471213 "Martensville"
 470071 "Biggar"
 470738 "Saskatoon"
 470381 "Humboldt"
 470413 "Kindersley"
 470724 "Rosetown"
 470455 "Lanigan"
 470995 "Wadena"
 470618 "Outlook"
 471007 "Watrous"
 471040 "Wynyard"
 470283 "Foam Lake"
 470127 "Canora"
 470398 "Kamsack"
 471045 "Yorkton"
 470912 "Swift Current"
 470527 "Melville"
 470294 "Fort Qu'Appelle"
 470502 "Maple Creek"
 470549 "Moose Jaw"
 471211 "Pilot Butte"
 471329 "Balgonie"
 470698 "Regina"
 471328 "White City"
 470749 "Shaunavon"
 470338 "Gravelbourg"
 470025 "Assiniboia"
 471016 "Weyburn"
 470141 "Carlyle"
 470620 "Oxbow"
 470270 "Estevan"
 470143 "Carnduff"
 470943 "Tisdale"
 471374 "Regina Beach"
 470385 "Indian Head"
 470478 "Lloydminster"
 470588 "Nipawin"
 471231 "Macklin"
 471212 "Dalmeny"
 470674 "Preeceville"
 471153 "Lumsden"
 470453 "Langenburg"
 470269 "Esterhazy"
 470551 "Moosomin"
 480371 "High Level"
 481347 "La Crte"
 480501 "Manning"
 480274 "Fairview"
 480342 "Grimshaw"
 480629 "Peace River"
 480777 "Spirit River"
 481242 "Sexsmith"
 481346 "Clairmont"
 481197 "Wembley"
 480336 "Grande Prairie"
 480292 "Fort McMurray"
 480372 "High Prairie"
 480972 "Valleyview"
 480764 "Slave Lake"
 480335 "Grande Cache"
 480301 "Fox Creek"
 480910 "Swan Hills"
 481022 "Whitecourt"
 480439 "Lac la Biche"
 480042 "Barrhead"
 480254 "Edson"
 481012 "Westlock"
 481174 "Jasper"
 481291 "Smoky Lake"
 480697 "Redwater"
 481141 "Gibbons"
 480330 "Grand Centre"
 480083 "Bonnyville"
 481258 "Stony Plain"
 481199 "Lamont"
 480796 "St. Paul"
 480237 "Drayton Valley"
 480226 "Devon"
 481302 "Two Hills"
 481202 "Beaumont"
 481360 "Calmar"
 480465 "Leduc"
 481165 "Tofield"
 480980 "Vegreville"
 481201 "Millet"
 481015 "Wetaskiwin"
 480123 "Camrose"
 480708 "Rimbey"
 480652 "Ponoka"
 480478 "Lloydminster"
 480446 "Lacombe"
 481303 "Killam"
 481173 "Blackfalds"
 480915 "Sylvan Lake"
 480996 "Wainwright"
 481198 "Penhold"
 480890 "Stettler"
 480387 "Innisfail"
 481387 "Bowden"
 481164 "Sundre"
 480607 "Olds"
 480227 "Didsbury"
 480683 "Provost"
 481140 "Carstairs"
 480934 "Three Hills"
 480040 "Banff"
 481216 "Crossfield"
 480191 "Cochrane"
 480003 "Airdrie"
 481369 "Irricana"
 480239 "Drumheller"
 481368 "Chestermere"
 481367 "Langdon"
 480898 "Strathmore"
 481139 "Black Diamond"
 480606 "Okotoks"
 480373 "High River"
 481279 "Bassano"
 480993 "Vulcan"
 480101 "Brooks"
 480183 "Claresholm"
 480074 "Blairmore"
 480643 "Picture Butte"
 481249 "Coalhurst"
 480646 "Pincher Creek"
 480188 "Coaldale"
 480467 "Lethbridge"
 480916 "Taber"
 480086 "Bow Island"
 480496 "Magrath"
 480693 "Raymond"
 480138 "Cardston"
 480052 "Beaverlodge"
 481311 "Athabasca"
 481200 "Elk Point"
 480988 "Viking"
 480694 "Red Deer"
 480351 "Hanna"
 480115 "Calgary"
 480291 "Fort Macleod"
 481214 "Bon Accord"
 480517 "Mayerthorpe"
 480554 "Morinville"
 480720 "Rocky Mountain House"
 480374 "Hinton"
 480780 "Spruce Grove"
 480252 "Edmonton"
 480982 "Vermilion"
 480125 "Canmore"
 481138 "Nanton"
 480523 "Medicine Hat"
 590293 "Fort Nelson"
 590922 "Terrace"
 590765 "Smithers"
 590420 "Kitimat"
 590298 "Fort St. John"
 591221 "Houston"
 590493 "Mackenzie"
 590110 "Burns Lake"
 590217 "Dawson Creek"
 590297 "Fort St. James"
 590304 "Fraser Lake"
 591240 "Tumbler Ridge"
 590679 "Prince George"
 590687 "Quesnel"
 591087 "Port Hardy"
 591190 "Port McNeill"
 591028 "Williams Lake"
 591047 "One Hundred Mile House"
 590325 "Gold River"
 590119 "Campbell River"
 590207 "Courtenay"
 590673 "Powell River"
 590213 "Cumberland"
 590470 "Lillooet"
 590112 "Cache Creek"
 591351 "Pemberton"
 590024 "Ashcroft"
 591309 "Whistler"
 590654 "Port Alberni"
 590959 "Ucluelet"
 590397 "Kamloops"
 590626 "Parksville"
 590781 "Squamish"
 591222 "Dallas"
 591350 "Blind Bay"
 591300 "Sechelt"
 591376 "Roberts Creek"
 590316 "Gibsons"
 591219 "Sicamous"
 591217 "Lions Bay"
 590736 "Salmon Arm"
 590700 "Revelstoke"
 590568 "Nanaimo"
 590529 "Merritt"
 590447 "Ladysmith"
 590020 "Armstrong"
 590449 "Lake Cowichan"
 590169 "Chemainus"
 591375 "Crofton"
 591253 "Walnut Grove"
 590983 "Vernon"
 591175 "Lumby"
 590973 "Vancouver"
 591218 "Aldergrove"
 591377 "Harrison Hot Springs"
 591349 "Shawnigan"
 590376 "Hope"
 591262 "Duck Lake"
 591378 "Mill Bay"
 590177 "Chilliwack"
 591314 "Cultus Lake"
 590403 "Kelowna"
 591098 "Sooke"
 590681 "Princeton"
 590567 "Nakusp"
 590984 "Victoria"
 591117 "Summerland"
 590389 "Invermere"
 590632 "Penticton"
 590608 "Oliver"
 590615 "Osoyoos"
 590574 "Nelson"
 591143 "Elkford"
 590146 "Castlegar"
 590333 "Grand Forks"
 590411 "Kimberley"
 591257 "Rossland"
 590948 "Trail"
 591171 "Salmo"
 590776 "Sparwood"
 590210 "Cranbrook"
 590280 "Fernie"
 590212 "Creston"
 590680 "Prince Rupert"
 590161 "Chase"
 590243 "Duncan"
 591325 "Kent"
 590307 "Fruitvale"
 591144 "Logan Lake"
 591021 "White Rock"
 591048 "Abbotsford"
 590174 "Chetwynd"
 590974 "Vanderhoof"
 590326 "Golden"
 590262 "Enderby"
 601023 "Whitehorse"
 610388 "Inuvik"
 611044 "Yellowknife"
 610366 "Hay River"
 621392 "Cambridge Bay"
 621293 "Pangnirtung"
 620306 "Iqaluit"
 621393 "Arviat"
 621320 "Rankin Inlet"
 109910 "Newfoundland and Labrador Rural Area"
 119911 "Prince Edward Island Rural Area"
 129912 "Nova Scotia Rural Area"
 139913 "New Brunswick Rural Area"
 249924 "Quebec Rural Area"
 359935 "Ontario Rural Area"
 469946 "Manitoba Rural Area"
 479947 "Saskatchewan Rural Area"
 489948 "Alberta Rural Area"
 599959 "British Columbia Rural Area"
 609960 "Yukon Territory Rural Area"
 619961 "Northwest Territories Rural Area"
 629962 "Nunavut Rural Area"
 /
 PCRASIZE
 0 "No code assigned, reason unknown"
 1 "rural area"
 2 "small population centre (1,000 to 29,999)"
 3 "medium population centre (30,000 to 99,999)"
 4 "large urban population centre (100,000 or greater)"
 .

missing values
 PCRACODE
 (0,9910 thru 9962)
 urbnarea
 (0)
 pcratype
 (9).

* By default, in order to be compatible with older versions of SPSS, an eight-character variable name
*  has been used. However, the longer names distributed by Canada Post are assigned below: if you wish
*  to use them, remove the asterisk from each line (remove the comment).

* rename variables (PCRACODE=POP_CNTR_RA).
* rename variables (PCRATYPE=POP_CNTR_RA_type).
* rename variables (blockcod=dissemination_block).
* rename variables (reppoint=rep_pt_type).
* rename variables (commname=comm_name).
* rename variables (brthdate=birth_date).
* rename variables (rtrddate=ret_date).
* rename variables (latitude=lat).
* rename variables (longitud=long).
* RENAME VARIABLES (PCRASIZE=POP_CNTR_RA_SIZE_CLASS).

* This command will save the SPSS system file as pccf201306m - assuming it to be a best match (m) file.
* If run on an "all records" file, change the "m" in the file name to "a".

save outfile='[path]\pccf201306m.sav'.

